/*
 * dsm_pub.h
 *
 * huawei device state monitor public head file
 *
 * Copyright (c) 2015-2019 Huawei Technologies Co., Ltd.
 *
 * This software is licensed under the terms of the GNU General Public
 * License version 2, as published by the Free Software Foundation, and
 * may be copied, distributed, and modified under those terms.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 */

#ifndef _DSM_PUB_H
#define _DSM_PUB_H

#include <linux/kernel.h>
#include <linux/version.h>
#include <linux/wait.h>
#include <linux/workqueue.h>

/* max client name length */
#define CLIENT_NAME_LEN				32
/* max device name length */
#define DSM_MAX_DEVICE_NAME_LEN			32
/* max module name length */
#define DSM_MAX_MODULE_NAME_LEN			16
/* max ic name length */
#define DSM_MAX_IC_NAME_LEN			16
/* dsm error no define */
#define DSM_ERR_NO_ERROR			0
#define DSM_ERR_I2C_TIMEOUT			1

/* pmu irq */
#define DSM_PMU_IRQ_ERROR_NO                        920005000
#define DSM_PMU_VSYS_OV_D200UR_ERROR_NO             920005002
#define DSM_PMU_VSYS_UV_D10MR_ERROR_NO              920005003
#define DSM_PMU_VSYS_PWROFF_ABS_2D_ERROR_NO         920005004
#define DSM_PMU_VSYS_PWROFF_DEB_D80MR_ERROR_NO      920005005
#define DSM_PMU_VSYS_THSD_OTMP140_D1MR_ERROR_NO     920005006
#define DSM_PMU_VSYS_THSD_OTMP125_D1MR_ERROR_NO     920005007

/* pmu ocp */
#define DSM_PMU_OCP_ERROR_NO_BASE                   920007000
#define DSM_PMU_OCPLDO2_ERROR_NO                    920007000
#define DSM_PMU_OCPLDO1_ERROR_NO                    920007001
#define DSM_PMU_OCPLDO0_ERROR_NO                    920007002
#define DSM_PMU_OCPBUCK4_ERROR_NO                   920007003
#define DSM_PMU_OCPBUCK3_ERROR_NO                   920007004
#define DSM_PMU_OCPBUCK2_ERROR_NO                   920007005
#define DSM_PMU_OCPBUCK1_ERROR_NO                   920007006
#define DSM_PMU_OCPBUCK0_ERROR_NO                   920007007
#define DSM_PMU_OCPLDO11_ERROR_NO                   920007008
#define DSM_PMU_OCPLDO10_ERROR_NO                   920007009
#define DSM_PMU_OCPLDO9_ERROR_NO                    920007010
#define DSM_PMU_OCPLDO8_ERROR_NO                    920007011
#define DSM_PMU_OCPLDO7_ERROR_NO                    920007012
#define DSM_PMU_OCPLDO5_ERROR_NO                    920007013
#define DSM_PMU_OCPLDO4_ERROR_NO                    920007014
#define DSM_PMU_OCPLDO3_ERROR_NO                    920007015
#define DSM_PMU_OCPLDO20_ERROR_NO                   920007016
#define DSM_PMU_OCPLDO19_ERROR_NO                   920007017
#define DSM_PMU_OCPLDO17_ERROR_NO                   920007018
#define DSM_PMU_OCPLDO16_ERROR_NO                   920007019
#define DSM_PMU_OCPLDO15_ERROR_NO                   920007020
#define DSM_PMU_OCPLDO14_ERROR_NO                   920007021
#define DSM_PMU_OCPLDO13_ERROR_NO                   920007022
#define DSM_PMU_OCPLDO12_ERROR_NO                   920007023
#define DSM_PMU_OCPLDO28_ERROR_NO                   920007024
#define DSM_PMU_OCPLDO27_ERROR_NO                   920007025
#define DSM_PMU_OCPLDO26_ERROR_NO                   920007026
#define DSM_PMU_OCPLDO25_ERROR_NO                   920007027
#define DSM_PMU_OCPLDO24_ERROR_NO                   920007028
#define DSM_PMU_OCPLDO23_ERROR_NO                   920007029
#define DSM_PMU_OCPLDO22_ERROR_NO                   920007030
#define DSM_PMU_OCPLDO21_ERROR_NO                   920007031
#define DSM_PMU_CLASSD_OCP_ERROR_NO                 920007032
#define DSM_PMU_OCPLDO32_ERROR_NO                   920007036
#define DSM_PMU_OCPLDO31_ERROR_NO                   920007037
#define DSM_PMU_OCPLDO30_ERROR_NO                   920007038
#define DSM_PMU_OCPLDO29_ERROR_NO                   920007039
#define DSM_PMU_BUCK4_SCP_ERROR_NO                  920007040
#define DSM_PMU_BUCK3_SCP_ERROR_NO                  920007041
#define DSM_PMU_BUCK2_SCP_ERROR_NO                  920007042
#define DSM_PMU_BUCK1_SCP_ERROR_NO                  920007043
#define DSM_PMU_BUCK0_SCP_ERROR_NO                  920007044
#define DSM_PMU_OCPBUCK7_ERROR_NO                   920007045
#define DSM_PMU_OCPBUCK6_ERROR_NO                   920007046
#define DSM_PMU_OCPBUCK5_ERROR_NO                   920007047
#define DSM_PMU_OCPBUCK8_ERROR_NO                   920007048
#define DSM_PMU_OCPLDO6_ERROR_NO                    920007049
#define DSM_PMU_OCPLDO33_ERROR_NO                   920007050
#define DSM_PMU_OCPLDO34_ERROR_NO                   920007051
#define DSM_PMU_OCPLDO35_ERROR_NO                   920007052
#define DSM_PMU_OCPLDO36_ERROR_NO                   920007053
#define DSM_PMU_BUCK7_SCP_ERROR_NO                  920007054
#define DSM_PMU_BUCK6_SCP_ERROR_NO                  920007055
#define DSM_PMU_BUCK5_SCP_ERROR_NO                  920007056
#define DSM_PMU_BUCK8_SCP_ERROR_NO                  920007057
#define DSM_PMU_LDOBUFF_SCP_ERROR_NO                920007058
#define DSM_PMU_OCPLDO18_ERROR_NO                   920007059
#define DSM_PMU_OCPPMUH_ERROR_NO                    920007060
#define DSM_PMU_OCPLDO37_ERROR_NO                   920007061
#define DSM_PMU_OCPBUCK00_ERROR_NO                  920007062
#define DSM_PMU_OCPBUCK01_ERROR_NO                  920007063
#define DSM_PMU_OCPBUCK02_ERROR_NO                  920007064
#define DSM_PMU_OCPBUCK9_ERROR_NO                   920007065
#define DSM_PMU_OCPLDO41_ERROR_NO                   920007066
#define DSM_PMU_OCPLDO40_ERROR_NO                   920007067
#define DSM_PMU_OCPLDO39_ERROR_NO                   920007068
#define DSM_PMU_OCPLDO38_ERROR_NO                   920007069
#define DSM_PMU_BUCK00_SCP_ERROR_NO                 920007070
#define DSM_PMU_BUCK02_SCP_ERROR_NO                 920007071
#define DSM_PMU_BUCK9_SCP_ERROR_NO                  920007072
#define DSM_PMU_OCPACR_ERROR_NO                     920007073

#define DSM_PMU_OCPBUCK10_ERROR_NO                  920007074
#define DSM_PMU_BUCK10_SCP_ERROR_NO                 920007075
#define DSM_LGA_CHECK_ERROR_NO                      920007076

#define DSM_PMU_OCPBUCK40_ERROR_NO                  920007077
#define DSM_PMU_OCPBUCK41_ERROR_NO                  920007078
#define DSM_PMU_OCPBUCK42_ERROR_NO                  920007079
#define DSM_PMU_OCPBUCK43_ERROR_NO                  920007080
#define DSM_PMU_OCPBUCK44_ERROR_NO                  920007081
#define DSM_PMU_SCPBUCK40_ERROR_NO                  920007082
#define DSM_PMU_SCPBUCK41_ERROR_NO                  920007083
#define DSM_PMU_SCPBUCK42_ERROR_NO                  920007084
#define DSM_PMU_SCPBUCK43_ERROR_NO                  920007085
#define DSM_PMU_SCPBUCK44_ERROR_NO                  920007086
#define DSM_PMU_OVPBUCK40_ERROR_NO                  920007087
#define DSM_PMU_OVPBUCK41_ERROR_NO                  920007088
#define DSM_PMU_OVPBUCK42_ERROR_NO                  920007089
#define DSM_PMU_OVPBUCK43_ERROR_NO                  920007090
#define DSM_PMU_OVPBUCK44_ERROR_NO                  920007091
#define DSM_PMU_CURBUCK40_ERROR_NO                  920007092
#define DSM_PMU_CURBUCK41_ERROR_NO                  920007093
#define DSM_PMU_CURBUCK42_ERROR_NO                  920007094
#define DSM_PMU_OCPLDO42_ERROR_NO                   920007095
#define DSM_PMU_OCPLDO43_ERROR_NO                   920007096
#define DSM_PMU_OCPLDO44_ERROR_NO                   920007097
#define DSM_PMU_OCPLDO45_ERROR_NO                   920007098
#define DSM_PMU_OCPLDO46_ERROR_NO                   920007099
#define DSM_PMU_OCPLDO47_ERROR_NO                   920007100
#define DSM_PMU_OCPLDO48_ERROR_NO                   920007101
#define DSM_PMU_OCPLDO49_ERROR_NO                   920007102
#define DSM_PMU_OCPLDO50_ERROR_NO                   920007103
#define DSM_PMU_OCPSW1_ERROR_NO                     920007104
#define DSM_PMU_VSYSSURGE_ERROR_NO                  920007105
#define DSM_PMU_OTMP125_ERROR_NO                    920007106
#define DSM_PMU_OCPBUCK11_ERROR_NO                  920007107
#define DSM_PMU_OCPBUCK20_ERROR_NO                  920007108
#define DSM_PMU_OCPBUCK21_ERROR_NO                  920007109
#define DSM_PMU_OCPBUCK30_ERROR_NO                  920007110
#define DSM_PMU_OCPBUCK31_ERROR_NO                  920007111
#define DSM_PMU_OCPBUCKBOOST_ERROR_NO               920007112
#define DSM_PMU_OCPBUCK12_ERROR_NO                  920007113
#define DSM_PMU_OCPBUCK13_ERROR_NO                  920007114
#define DSM_PMU_SCPBUCK20_ERROR_NO                  920007115
#define DSM_PMU_SCPBUCK30_ERROR_NO                  920007116
#define DSM_PMU_SCPBUCKBOOST_ERROR_NO               920007117
#define DSM_PMU_SCPBUCK12_ERROR_NO                  920007118
#define DSM_PMU_SCPBUCK13_ERROR_NO                  920007119
#define DSM_PMU_OVPBUCKBOOST_ERROR_NO               920007120
#define DSM_PMU_OVPBUCK12_ERROR_NO                  920007121
#define DSM_PMU_OVPBUCK20_ERROR_NO                  920007122
#define DSM_PMU_OVPBUCK30_ERROR_NO                  920007123
#define DSM_PMU_CURBUCK12_ERROR_NO                  920007124
#define DSM_PMU_CURBUCK00_ERROR_NO                  920007125
#define DSM_PMU_CURBUCK10_ERROR_NO                  920007126
#define DSM_PMU_CURBUCK20_ERROR_NO                  920007127
#define DSM_PMU_CURBUCK30_ERROR_NO                  920007128
#define DSM_PMU_OCPSUBPMUH_ERROR_NO                 920007129
#define DSM_PMU_OCPSW10_ERROR_NO                    920007130
#define DSM_PMU_OCPLDO51_ERROR_NO                   920007131
#define DSM_PMU_OCPLDO52_ERROR_NO                   920007132
#define DSM_PMU_OCPLDO53_ERROR_NO                   920007133
#define DSM_PMU_OCPLDO54_ERROR_NO                   920007134
#define DSM_PMU_OTMP125SUBPMU_ERROR_NO              920007135
#define DSM_PMU_OVPBUCK8_ERROR_NO                   920007136
#define DSM_PMU_OVPBUCK00_ERROR_NO                  920007137
#define DSM_PMU_OVPBUCK10_ERROR_NO                  920007138
#define DSM_PMU_OTMP140SUBPMU_ERROR_NO              920007139

#define DSM_PMU_OCPBUCK70_ERROR_NO                  920007140
#define DSM_PMU_OCPBUCK71_ERROR_NO                  920007141
#define DSM_PMU_OCPSINK_ERROR_NO                    920007142

#define DSM_PMU_SCPBUCK70_ERROR_NO                  920007143
#define DSM_PMU_SCPBUCK71_ERROR_NO                  920007144
#define DSM_PMU_SCPSINK_ERROR_NO                    920007145

#define DSM_PMU_OVPBUCK70_ERROR_NO                  920007146
#define DSM_PMU_OVPBUCK71_ERROR_NO                  920007147

#define DSM_PMU_VPROC1_OVER_LOAD                    920007148
#define DSM_PMU_VPROC2_OVER_LOAD                    920007149
#define DSM_PMU_VCORE_OVER_LOAD                     920007150
#define DSM_PMU_VPU_OVER_LOAD                       920007151
#define DSM_PMU_VPA_OVER_LOAD                       920007152
#define DSM_PMU_VGPU11_OVER_LOAD                    920007153
#define DSM_PMU_VGPU12_OVER_LOAD                    920007154
#define DSM_PMU_VMODEM_OVER_LOAD                    920007155
#define DSM_PMU_VS2_OVER_LOAD                       920007156
#define DSM_PMU_VS1_OVER_LOAD                       920007157
#define DSM_PMU_VFE28_OVER_LOAD                     920007158
#define DSM_PMU_VAUX18_OVER_LOAD                    920007159
#define DSM_PMU_VBIF28_OVER_LOAD                    920007160
#define DSM_PMU_VUSB_OVER_LOAD                      920007161
#define DSM_PMU_VIBR_OVER_LOAD                      920007162
#define DSM_PMU_VCN33_1_OVER_LOAD                   920007163
#define DSM_PMU_VCN33_2_OVER_LOAD                   920007164
#define DSM_PMU_VEMC_OVER_LOAD                      920007165
#define DSM_PMU_VSIM1_OVER_LOAD                     920007166
#define DSM_PMU_VSIM2_OVER_LOAD                     920007167
#define DSM_PMU_VIO28_OVER_LOAD                     920007168
#define DSM_PMU_VUFS_OVER_LOAD                      920007169
#define DSM_PMU_VCN18_OVER_LOAD                     920007170
#define DSM_PMU_VRF18_OVER_LOAD                     920007171
#define DSM_PMU_VIO18_OVER_LOAD                     920007172
#define DSM_PMU_VEFUSE_OVER_LOAD                    920007173
#define DSM_PMU_VM18_OVER_LOAD                      920007174
#define DSM_PMU_VCAMIO_OVER_LOAD                    920007175
#define DSM_PMU_VAUD18_OVER_LOAD                    920007176
#define DSM_PMU_VA09_OVER_LOAD                      920007177
#define DSM_PMU_VA12_OVER_LOAD                      920007178
#define DSM_PMU_VCN13_OVER_LOAD                     920007179
#define DSM_PMU_VSRAM_MD_OVER_LOAD                  920007180
#define DSM_PMU_VSRAM_PROC1_OVER_LOAD               920007181
#define DSM_PMU_VSRAM_PROC2_OVER_LOAD               920007182
#define DSM_PMU_VSRAM_OTHERS_OVER_LOAD              920007183
#define DSM_PMU_VRF12_OVER_LOAD                     920007184
#define DSM_PMU_VBUCK1_OVER_LOAD                    920007185
#define DSM_PMU_VBUCK2_OVER_LOAD                    920007186
#define DSM_PMU_VBUCK3_OVER_LOAD                    920007187
#define DSM_PMU_VBUCK4_OVER_LOAD                    920007188
#define DSM_PMU_BUCK2_OVER_LOAD                     920007189
#define DSM_PMU_BUCK1_OVER_LOAD                     920007190
#define DSM_PMU_LDO1_OVER_LOAD                      920007191
#define DSM_PMU_LDO2_OVER_LOAD                      920007192
#define DSM_PMU_LDO3_OVER_LOAD                      920007193
#define DSM_PMU_LDO5_OVER_LOAD                      920007194
#define DSM_PMU_LDO6_OVER_LOAD                      920007195
#define DSM_PMU_LDO7_OVER_LOAD                      920007196

/* pmu independence */
#define DSM_PMU_EXP                                 925206400
/* charger */
#define DSM_CHARGER_ERROR_NO                        920011000

/* pmu coul */
#define DSM_PMU_COUL_ERROR_NO                       920006000

/* battery detect */
#define DSM_BATTERY_DETECT_ERROR_NO                 920002000
#define DSM_BATTERY_ROM_ID_CERTIFICATION_FAIL       920002001
#define DSM_BATTERY_IC_EEPROM_STATE_ERROR           920002002
#define DSM_BATTERY_IC_KEY_CERTIFICATION_FAIL       920002003
#define DSM_OLD_BOARD_AND_OLD_BATTERY_UNMATCH       920002004
#define DSM_OLD_BOARD_AND_NEW_BATTERY_UNMATCH       920002005
#define DSM_NEW_BOARD_AND_OLD_BATTERY_UNMATCH       920002006
#define DSM_BATTERY_NV_DATA_READ_FAIL               920002007
#define DSM_CERTIFICATION_SERVICE_IS_NOT_RESPONDING 920002008
#define DSM_UNMATCH_BATTERYS                        920002009

/* battery */
#define DSM_BATTERY_ERROR_NO_BASE                   920001000
#define ERROR_BATT_NOT_EXIST                        920001003
#define ERROR_BATT_TEMP_LOW                         920001004
#define ERROR_BATT_VOLT_HIGH                        920001005
#define ERROR_BATT_VOLT_LOW                         920001006
#define ERROR_BATT_TERMINATE_TOO_EARLY              920001007
#define ERROR_BATT_NOT_TERMINATE                    920001008
#define ERROR_BATT_BAD_CURR_SENSOR                  920001009
#define ERROR_VBUS_VOLT_HIGH                        920001010
#define ERROR_WATCHDOG_RESET                        920001011
#define ERROR_CHARGE_CURR_OVERHIGH                  920001012
#define ERROR_DISCHARGE_CURR_OVERHIGH               920001013
#define ERROR_CHARGE_CURR_ZERO                      920001014
#define ERROR_CHARGE_TEMP_FAULT                     920001015
#define ERROR_CHARGE_BATT_TEMP_SHUTDOWN             920001016
#define ERROR_CHARGE_BATT_CAPACITY                  920001017
#define ERROR_CHARGE_CHARGER_TS                     920001018
#define ERROR_CHARGE_OTG                            920001019
#define ERROR_FCP_VOL_OVER_HIGH                     920001021
#define ERROR_FCP_DETECT                            920001022
#define ERROR_FCP_OUTPUT                            920001023
#define ERROR_SWITCH_ATTACH                         920001024
#define ERROR_ADAPTER_OVLT                          920001025
#define ERROR_ADAPTER_OCCURRENT                     920001026
#define ERROR_ADAPTER_OTEMP                         920001027
#define ERROR_SAFE_PLOICY_LEARN                     920001028
#define ERROR_SAFE_PLOICY_LEARN1                    920001029
#define ERROR_WEAKSOURCE_HAPPEN                     920001030
#define ERROR_SAFE_PLOICY_LEARN2                    920001031
#define ERROR_SAFE_PLOICY_LEARN3                    920001032
#define ERROR_BOOST_OCP                             920001033
#define ERROR_CHARGE_I2C_RW                         920001034
#define ERROR_BATT_SOC_CHANGE_FAST                  920001035
#define ERROR_CHARGE_VBAT_OVP                       920001036
#define ERROR_SAFE_PLOICY_LEARN4                    920001037
/* log_mask 71 */
#define SHB_ERR_FCP_VOL_OVER_HIGH                   920001038
#define SHB_ERR_FCP_DETECT                          920001039
#define SHB_ERR_FCP_OUTPUT                          920001040
#define SHB_ERR_SWITCH_ATTACH                       920001041
#define SHB_ERR_ADAPTER_OVLT                        920001042
#define SHB_ERR_ADAPTER_OCCURRENT                   920001043
#define SHB_ERR_ADAPTER_OTEMP                       920001044
#define SHB_ERR_BOOST_OCP                           920001045
/* internal short current detect */
#define DSM_BATTERY_ISCD_LEVEL0                     920001048
#define DSM_BATTERY_ISCD_LEVEL1                     920001049
#define DSM_BATTERY_ISCD_LEVEL2                     920001050
#define DSM_BATTERY_ISCD_LEVEL3                     920001051
#define DSM_BATTERY_ISCD_LEVEL4                     920001052
#define DSM_BATTERY_ISCD_LEVEL5                     920001053
#define DSM_BATTERY_ISCD_LEVEL6                     920001054
#define DSM_BATTERY_ISCD_LEVEL7                     920001055
#define DSM_BATTERY_ISCD_LEVEL8                     920001056
/* log_mask 71 */
#define SHB_ERR_VBUS_HIGH                           920001057
#define SHB_ERR_VBAT_OVP                            920001058

#define DSM_DIRECT_CHARGE_ERR_WITH_NONSTD_CABLE     920001059
#define DSM_DIRECT_CHARGE_VOL_ACCURACY              920001060
#define DSM_DIRECT_CHARGE_FULL_PATH_RESISTANCE      920001061
#define DSM_DIRECT_CHARGE_ERR_WITH_STD_CABLE        920001062
#define DSM_DIRECT_CHARGE_USB_PORT_LEAKAGE_CURRENT  920001063
#define DSM_DIRECT_CHARGE_VBUS_OVP                  920001064
#define DSM_DIRECT_CHARGE_REVERSE_OCP               920001065
#define DSM_DIRECT_CHARGE_OTP                       920001066
#define DSM_DIRECT_CHARGE_INPUT_OCP                 920001067
#define DSM_DIRECT_CHARGE_ADAPTER_OTP               920001068
#define ERROR_WEAKSOURCE_STOP_CHARGE                920001069
#define ERROR_CHARGE_TEMP_WARM                      920001070
#define ERROR_VBUS_VOL_OVER_13400MV                 920001072
#define ERROR_COUL_ROLLBACK                         920001073
#define ERROR_LOW_VOL_INT                           920001074
#define ERROR_REFRESH_FCC_OUTSIDE                   920001075
#define ERROR_RESUME_SOC_JUMP                       920001076
#define ERROR_FATAL_ISC_CASE1                       920001077
#define ERROR_FATAL_ISC_CASE2                       920001078
#define ERROR_WIRELESS_CHECK_TX_ABILITY_FAIL        920001079
#define ERROR_WIRELESS_CERTI_COMM_FAIL              920001080
#define ERROR_WIRELESS_CERTI_SERVICE_FAIL           920001081
#define ERROR_WIRELESS_BOOSTING_FAIL                920001082
#define ERROR_WIRELESS_ERROR                        920001083
#define ERROR_WIRELESS_RX_OCP                       920001084
#define ERROR_WIRELESS_RX_OTP                       920001085
#define ERROR_WIRELESS_RX_OVP                       920001086
#define ERROR_WIRELESS_STATISTICS                   920001087
#define DSM_BATTERY_CHANGED_NO                      920001090
#define DSM_BATTERY_DRAINED_NO                      920001091
#define ERROR_WIRELESS_TX_POWER_SUPPLY_FAIL         920001092
#define ERROR_WIRELESS_TX_BATTERY_OVERHEAT          920001093
#define ERROR_WIRELESS_TX_CEP_TIMEOUT               920001094
#define ERROR_WIRELESS_TX_STATISTICS                920001095
#define DSM_BATTERY_ASW_PROTECT_H1_SCENE            920001096
#define DSM_BATTERY_ASW_PROTECT_H2_SCENE            920001097
#define DSM_BATTERY_ASW_PROTECT_NORMAL_SCENE        920001098
#define DSM_MULTI_CHARGE_CURRENT_RATIO_ERROR        920001108
#define DSM_MULTI_CHARGE_CURRENT_RATIO_WARNING      920001109
#define DSM_MULTI_CHARGE_CURRENT_RATIO_INFO         920001110
#define DSM_BATTERY_HEATING                         920001111
#define DSM_USB_PORT_TEMP_EXCEED_50                 920001112
#define DSM_USB_PORT_TEMP_EXCEED_55                 920001113
#define DSM_DIRECT_CHARGE_FULL_PATH_RESISTANCE_2ND  920001114

#define ERROR_BATT_ACR_OVER_THRESHOLD               920001089
#define ERROR_BATTERY_POLAR_ISHORT                  920001200
#define DSM_POWER_DEVICES_INFO                      920001201

/* otg mode: usb short circuit */
#define DSM_OTG_VBUS_SHORT                          920001207

/* wireless charge sw */
#define DSM_WLPS_GPIO_TXSW                          920001209

#define DSM_SOFT_RECHARGE_NO                        920001210

/* wireless lightstrap */
#define DSM_LIGHTSTRAP_STATUS                       920002010

/* water check */
#define ERROR_NO_WATER_CHECK_BASE                   920014000
#define ERROR_NO_WATER_CHECK_IN_USB                 920014000
#define ERROR_NO_WATER_CHECK_IN_EAR                 920014001
#define ERROR_NO_WATER_CHECK_IN_SIM                 920014002
#define ERROR_NO_WATER_CHECK_IN_KEY                 920014003
#define ERROR_NO_WATER_CHECK_IN_TWO_POSITIONS       920014004
#define ERROR_NO_WATER_CHECK_IN_THREE_POSITIONS     920014005
#define ERROR_NO_TYPEC_CC_OVP                       920014006

/* direct charge sc */
#define DSM_DIRECT_CHARGE_SC_BASE                   920015000
#define DSM_DIRECT_CHARGE_SC_FAULT_IBAT_OCP         920015000
#define DSM_DIRECT_CHARGE_SC_FAULT_IBUS_OCP         920015001
#define DSM_DIRECT_CHARGE_SC_FAULT_TSBAT_OTP        920015002
#define DSM_DIRECT_CHARGE_SC_FAULT_VBUS_OVP         920015003
#define DSM_DIRECT_CHARGE_SC_FAULT_VBAT_OVP         920015004
#define DSM_DIRECT_CHARGE_SC_FAULT_TSBUS_OTP        920015005
#define DSM_DIRECT_CHARGE_SC_FAULT_TDIE_OTP         920015006
#define DSM_DIRECT_CHARGE_SC_FAULT_AC_OVP           920015007
#define DSM_DIRECT_CHARGE_SC_FAULT_CONV_OCP         920015008

/* keyboard */
#define DSM_KB_CONNECTED_STATUS_NO                  936005009

/* superswitch */
#define ERROR_SUPERSWITCH_BASE                      920013000
#define ERROR_SUPERSWITCH_I2C_ERROR                 920013000
#define ERROR_SUPERSWITCH_INT_STORM                 920013001
#define ERROR_SUPERSWITCH_ABNORMAL_PLUG             920013002
#define ERROR_SUPERSWITCH_VBUS_OVP                  920013003
#define ERROR_SUPERSWITCH_VBUS_ONLY                 920013004
#define ERROR_SUPERSWITCH_STATEMACHINE_STUCK        920013005
#define ERROR_SUPERSWITCH_VCONN_OCP                 920013006
#define ERROR_SUPERSWITCH_FORCE_DISCHARGE_FAIL      920013007

/* r1 customize */
#define ERROR_NON_STANDARD_CHARGER_PLUGGED          920008033
#define ERROR_CHARGER_REMOVED                       920008034

/* SMPL */
#define ERROR_NO_SMPL                               920003000

/* uscp */
#define ERROR_NO_USB_SHORT_PROTECT                  920004000
#define ERROR_NO_USB_SHORT_PROTECT_NTC              920004001
#define SHB_ERR_USB_SHORT_PROTECT                   920004002
#define SHB_ERR_USB_SHORT_PROTECT_NTC               920004003
#define ERROR_NO_USB_SHORT_PROTECT_HIZ              920004004

/* pd_richtek */
#define PD_RICHTEK_ERROR_NO_BASE                    926010000
#define ERROR_RT_DPSTS_BOTH_CONNECTED               926010000
#define ERROR_RT_UFP_INVALID                        926010001
#define ERROR_RT_DFP_INVALID                        926010002
#define ERROR_RT_OVER_VDO_MAX_SIZE                  926010003
#define ERROR_RT_PD_MSG_NULL                        926010004
#define ERROR_RT_DATA_OBJ_NULL                      926010005
#define ERROR_RT_OVER_VDO_MAX_SVID_SIZE             926010006
#define ERROR_RT_PD_NR_PE_STATES                    926010007
#define ERROR_RT_PD_TIMER_NR                        926010008
#define ERROR_RT_PD_ALLOC_MSG                       926010009
#define ERROR_RT_PD_FREE_MSG                        926010010
#define ERROR_RT_TCPC_DEV_NULL                      926010011
#define ERROR_RT_DATA_ROLE_ISNOT_PD_ROLE_DFP        926010012
#define ERROR_RT_SVID_DATA_NULL                     926010013

/* tp */
#define DSM_TP_I2C_RW_ERROR_NO			926004000
#define DSM_TP_FWUPDATE_ERROR_NO		926004001
#define DSM_TP_RAWDATA_ERROR_NO			926004002
#define DSM_TP_FW_CRC_ERROR_NO			926004003
#define DSM_TP_DEV_STATUS_ERROR_NO		926004004
#define DSM_TP_FREEZE_ERROR_NO			926004005
/* one possible reason:LCD can't send out TSVD/TSHD signal */
#define DSM_TP_IN_MOISTURE_ERROR_NO		926004008
#define DSM_TP_IN_VNOISE_ERROR_NO		926004009
#define DSM_TP_SENSIBILITY_CHANGE		936004015
#define DSM_TP_ESD_ERROR_NO			926004015
#define DSM_TP_WAKEUP_ERROR_NO			926004020
#define DSM_TP_IC_TIMEOUT_ERROR_NO		926004021
#define DSM_TP_STARTUP_FAIDED_ERROR_NO		926004022
#define DSM_TP_GHOST_TOUCH_ERROR_NO		926004024
#define DSM_TP_BOOT_DETECTION			926004025
#define DSM_TP_INIT_ERROR_NO			926004032
#define DSM_TP_ABNORMAL_DONT_AFFECT_USE_NO	926004033
#define DSM_TP_FWUPDATE_OVERTIME_ERROR_NO	926004035
#define DSM_TP_GND_CONNECTION_ABNORMAL		926004036
#define DSM_TP_TX_SNS_ABNORMAL			926004037
#define DSM_TP_RX_SNS_ABNORMAL			926004038
#define DSM_TP_PIXEL_SNS_ABNORMAL		926004039
#define DSM_TP_DISPLAY_LARGE_NOISE		926004040
#define DSM_TP_CHARGER_NOISE_HOP		926004041
#define DSM_TP_CHARGER_NOISE_EX			926004042
#define DSM_TP_SELF_CAP_LARGE_NOISE		926004043
#define DSM_TP_MUTUAL_CAP_LARGE_NOISE		926004044
#define DSM_TP_HIGH_TEMP_MODE			926004045
#define DSM_TP_LOW_TEMP_MODE			926004046
#define DSM_TP_LARGE_BENDING			926004047
#define DSM_SHB_ERR_TP_INIT_ERROR		926004048
#define DSM_SHB_ERR_TP_I2C_ERROR		926004049
#define DSM_SHB_ERR_TP_ESD_ERROR		926004050

/* tphostprocessing */
#define DSM_TPHOSTPROCESSING_SPI_RW_ERROR_NO	926011021
#define DSM_TPHOSTPROCESSING_DEV_STATUS_ERROR_NO 926011022
#define DSM_TPHOSTPROCESSING_DEV_GESTURE_EXP1    926011044
#define DSM_TPHOSTPROCESSING_DEV_GESTURE_EXP2    926011045
#define DSM_TPHOSTPROCESSING_DEV_UDFP_EXP1       926011046
#define DSM_TPHOSTPROCESSING_DEV_UDFP_EXP2       926011047
#define DSM_TPHOSTPROCESSING_DEV_UDFP_EXP3       926011048

/* DP */
#define DSM_DP_BASIC_EXTERNAL_DISPLAY_NO	936000100
#define DSM_DP_BASIC_DISPLAY_TIME_NO		936000101

/* lcd */
#define DSM_LCD_LDI_UNDERFLOW_NO		922001000
#define DSM_LCD_LDI_UNDERFLOW_ERROR_NO		922001000
#define DSM_LCD_TE_TIME_OUT_ERROR_NO		922001001
#define DSM_LCD_STATUS_ERROR_NO			922001002
#define DSM_LCD_POWER_STATUS_ERROR_NO		922001003
#define DSM_LCD_PWM_ERROR_NO			922001004
#define DSM_LCD_BRIGHTNESS_ERROR_NO		922001005
#define DSM_LCD_ESD_RECOVERY_NO			922001006
#define DSM_LCD_ESD_OCP_RECOVERY_NO		922001007
#define DSM_LCD_OVP_ERROR_NO			922001008
#define DSM_LCD_OVP_COMFORT_MODE_NO		922001009
#define DSM_LCD_MIPI_ERROR_NO			922001010
#define DSM_LCD_MDSS_MDP_GPU_ERROR_NO		922001013
#define DSM_LCD_OTP_ERROR_NO			922001014
#define DSM_LCD_MDSS_DSI_ISR_ERROR_NO		922001016
#define DSM_LCD_MDSS_MDP_ISR_ERROR_NO		922001017
#define DSM_LCD_ESD_STATUS_ERROR_NO		922001018
#define DSM_LCD_ESD_RESET_ERROR_NO		922001019
#define DSM_LCD_POWER_STATUS_ERROR_NO_QCOM	922001020
#define DSM_LCD_MDSS_UNDERRUN_ERROR_NO		922001021
#define DSM_LCD_MDSS_IOMMU_ERROR_NO		922001022
#define DSM_LCD_MDSS_PIPE_ERROR_NO		922001023
#define DSM_LCD_MDSS_PINGPONG_ERROR_NO		922001024
#define DSM_LCD_MDSS_VSP_VSN_ERROR_NO		922001025
#define DSM_LCD_MDSS_ROTATOR_ERROR_NO		922001026
#define DSM_LCD_MDSS_FENCE_ERROR_NO		922001027
#define DSM_LCD_MDSS_CMD_STOP_ERROR_NO		922001028
#define DSM_LCD_MDSS_VIDEO_DISPLAY_ERROR_NO	922001029
#define DSM_LCD_MDSS_MDP_CLK_ERROR_NO		922001030
#define DSM_LCD_MDSS_MDP_BUSY_ERROR_NO		922001031
#define DSM_LCD_FB0_CLOSE_ERROR_NO		922001032
#define DSM_LCD_BTB_CHECK_ERROR_NO		922001033
#define DSM_LCD_BACKLIGHT_OCP_ERROR_NO		922001034
#define DSM_LCD_BACKLIGHT_TSD_ERROR_NO		922001035
#define DSM_LCD_MIPI_TRANSMIT_ERROR_NO		922001036
#define DSM_LCD_OFFLINE_COMPOSE_TIMEOUT_NO	922001037
#define DSM_LCD_VACTIVE_TIMEOUT_ERROR_NO	922001038
#define DSM_LCD_CREATE_FENCE_FAIL_NO		922001039
#define DSM_LCD_BACKLIGHT_I2C_ERROR_NO		922001040
#define DSM_LCD_BIAS_I2C_ERROR_NO		922001041
#define DSM_LCD_BACKLIGHT_FLICKER_ERROR_NO	922001042
#define DSM_LCD_SET_POWER_MODE_RECOVERY_ERROR_NO	922001044
#define DSM_LCD_PANEL_CRACK_ERROR_NO		922001501
#define DSM_LCD_CHECKSUM_ERROR_NO		922001502
#define DSM_LCD_POWER_ABNOMAL_ERROR_NO		922001503
#define DSM_LCD_DDIC_LV_DETECT_ERROR_NO		922001504
#define DSM_AMOLED_POWER_IC_CHECK_ERROR_NO	922001505
#define DSM_LCD_UNDERRUN_ERROR_NO	        922001506
#define DSM_LCD_CHANGE_FPS_ERROR_NO	        922001507
#define DSM_LCD_SN_CHECK_ERROR_NO		936004017
#define DSM_DSI_DETECT_ERROR_NO	            925004311

/* gpu */
#define DSM_LCD_GPU_HANG_ERROR_NO		922002000
#define DSM_LCD_GPU_PAGEFAULT_ERROR_NO		922002001
#define DSM_LCD_GPU_SOFTRESET_ERROR_NO		922002004
#define DSM_LCD_GPU_HARDRESET_ERROR_NO		922002005

#define DSM_SOC_HIFI_RESET			921001000
#define DSM_CODEC_HIFI_RESET			921001001
#define DSM_CODEC_HIFI_IF_OPEN_ERR		921001002
#define DSM_SOC_HIFI_HIGH_CPU			921001003

#define DSM_HI6402_PLL_PD			921001004
#define DSM_HI6402_PLL_UNLOCK			921001005
#define DSM_HI6402_PLL_CANNOT_LOCK		921001006
#define DSM_HI6402_SLIMBUS_READ_ERR		921001007
#define DSM_HI6402_SLIMBUS_LOST_MS		921001008
#define DSM_HI6402_MBHC_HS_ERR_TYPE		921001009
#define DSM_AUDIO_HAL_ERR_TYPE			921001015
#define DSM_SOC_HIFI_UPDATE_BUFF_DELAY		921001024
#define DSM_SOC_HIFI_3A_ERROR			921001031
#define DSM_CODEC_HIFI_TIMEOUT			921001032
/* hifi */
#define DSM_HIFI_AK4376_I2C_ERR			921001034
#define DSM_HIFI_AK4376_CODEC_PROBE_ERR		921001035
/* codec */
#define DSM_CODEC_BUNK1_OCP			921001036
#define DSM_CODEC_BUNK1_SCP			921001037
#define DSM_CODEC_BUNK2_OCP			921001038
#define DSM_CODEC_BUNK2_SCP			921001039
#define DSM_CODEC_CP1_SHORT			921001040
#define DSM_CODEC_CP2_SHORT			921001041
#define DSM_CODEC_LDO_AVDD18_OCP		921001048
#define DSM_CODEC_LDOP_OCP			921001049
#define DSM_CODEC_LDON_OCP			921001050
#define DSM_USBAUDIO_INFO			931001000

#define DSM_CODEC_HIFI_LOAD_FAIL		921001051
#define DSM_CODEC_HIFI_SYNC_TIMEOUT		921001052
#define DSM_SOC_HIFI_SYNC_TIMEOUT		921001053
#define DSM_PCM_DRV_UPDATE_PCM_BUFF_DELAY	921001054
#define DSM_CODEC_SSI_READ_ONCE			921001055
#define DSM_CODEC_CHECK_ERR                     921001057
#define DSM_B2_ADC_BATT_ERR		921001058
#define DSM_SHB_B2_GPIO_ERR		921001059
#define DSM_SHB_B2_ADC_BATT_ERR		921001060

/* hifi usb */
#define DSM_HIFIUSB_HC_DIED			921001044
#define DSM_HIFIUSB_START			921001045
#define DSM_HIFIUSB_ENUM_DEV			921001046
#define DSM_HIFIUSB_STOP			921001047

/* anc_hs */
#define ANC_HS_OPEN_BOOST_ERR			921002000
#define ANC_HS_CANCEL_WORK_BLOCK		921002001
#define ANC_HS_CLOSE_BOOST_ERR			921002002
#define ANC_HS_ADCH_READ_ERR			921002003
#define ANC_HS_ADC_FULL_ERR			921002004
#define ANC_HS_MIC_WITH_GPIO_ERR		921002005
#define ANC_HS_QUEUE_WORK_ERR			921002006
#define ANC_HS_BTN_NOT_IN_RANGE			921002007
#define ANC_HS_UNHANDLED_IRQ			921002008
#define ANC_HS_I2C_ERR				921002009

/* smartpa */
#define DSM_SMARTPA_I2C_ERR			921003000
#define DSM_SMARTPA_INT_ERR			921003001

/* sdio */
#define DSM_SDIO_RW_ERROR_NO			925002000
#define DSM_SDIO_DCM_INIT_ERROR_NO		925002001
#define DSM_SDIO_HARDWARE_LOCK_NO		925002002
#define DSM_SDIO_RW_TIMEOUT_NO			925002003
#define DSM_SDIO_ATTACH_ERR_NO			925002004
#define DSM_SDIO_CDM52_INVELADE_ARGUMENT_ERR_NO	925002005
#define DSM_SDIO_CDM52_R5_ERR_NO		925002006
#define DSM_SDIO_CDM52_R5_FUNCTION_NUMBER_ERR_NO	925002007
#define DSM_SDIO_CDM52_R5_OUT_OF_RANGE_ERR_NO	925002008
#define DSM_SDIO_CDM52__WAIT_FOR_CMD_ERR_NO	925002009
#define DSM_SDIO_CMD53_INVELADE_ARGUMENT_ERR_NO	925002010
#define DSM_SDIO_CMD53_ALLOC_TABLE_ERR_NO	925002011
#define DSM_SDIO_CMD53_CMD_ERR_NO		925002012
#define DSM_SDIO_CMD53_DATA_ERR_NO		925002013
#define DSM_SDIO_CMD53_R5_ERR_NO		925002014
#define DSM_SDIO_CMD53_R5_FUNCTION_NUMBER_ERR_NO	925002015
#define DSM_SDIO_CMD53_R5_OUT_OF_RANGE_ERR_NO	925002016
#define DSM_SIDO_UNKOWN_ERR_NO			925002017

/* ai */
#define DSM_AI_KERN_POWER_UP_ERR_NO		925010001
#define DSM_AI_KERN_WTD_TIMEOUT_ERR_NO		925010004

/* sensors */
#define DSM_SHB_ERR_IOM7_CFG_DATA		926005000
#define DSM_SHB_ERR_IOM7_CMD			926005001
#define DSM_SHB_ERR_IOM7_DYNLOAD		926005002
#define DSM_SHB_ERR_IOM7_DETECT_FAIL		926005003
#define DSM_SHB_ERR_IOM7_IPC_TIMEOUT		926005004
#define DSM_SHB_ERR_IOM7_OTHER			926005005
#define DSM_SHB_ERR_IOM7_READ			926005006
#define DSM_SHB_ERR_PS_OIL_POLLUTION		926005007
#define DSM_SHB_ERR_IOM7_WDG			926005008
#define DSM_SHB_ERR_ACCEL_DATA_UNCHANGE		926005009

#define DSM_SHB_ERR_GYRO_DATA_UNCHANGE		926006000
#define DSM_SHB_ERR_MAG_DATA_UNCHANGE		926006001
#define DSM_SHB_ERR_MCU_ALS			926006002
#define DSM_SHB_ERR_MCU_FUSION			926006003
#define DSM_SHB_ERR_MCU_GYRO			926006004
#define DSM_SHB_ERR_MCU_I2C_ERR			926006005
#define DSM_SHB_ERR_MCU_LABC			926006006
#define DSM_SHB_ERR_MCU_LIGHT			926006007
#define DSM_SHB_ERR_MCU_MAG			926006008
#define DSM_SHB_ERR_MCU_MOTION			926006009
#define DSM_SHB_ERR_MCU_OTHER			926006010
#define DSM_SHB_ERR_MCU_PDR			926006011
#define DSM_SHB_ERR_MCU_PEDOMETER		926006012
#define DSM_SHB_ERR_MCU_PS			926006013
#define DSM_SHB_ERR_MCU_SYS_MAIN_INIT		926006100
#define DSM_SHB_ERR_MCU_SYS_SERVER_INIT		926006101
#define DSM_SHB_ERR_MCU_TIMER_TIMEOUT		926006102
#define DSM_SHB_ERR_MCU_ACC_PERIOD_ERROR	926006103
#define DSM_SHB_ERR_MCU_CA			926006104
#define DSM_SHB_ERR_SYSCOUNT			926006105
#define DSM_AP_ERR_COLORSENSOR_DETECT		926006500

#define DSM_SHB_ERR_GSENSOR_I2C_ERR		926007000
#define DSM_SHB_ERR_GSENSOR_DATA_ABNORMAL	926007001
#define DSM_SHB_ERR_GSENSOR_DATA_ALL_ZERO	926007002
#define DSM_SHB_ERR_GSENSOR_DATA_NOT_UPDATE	926007003
#define DSM_SHB_ERR_LIGHT_I2C_ERR		926007004
#define DSM_SHB_ERR_LIGHT_IRQ_ERR		926007005
#define DSM_SHB_ERR_LIGHT_THRESHOLD_ERR		926007006
#define DSM_SHB_ERR_LIGHT_NO_IRQ		926007007
#define DSM_SHB_ERR_LIGHT_ENABLE_ERR		926007008
#define DSM_SHB_ERR_LIGHT_THRESHOLD_OUT		926007009
#define DSM_SHB_ERR_LIGHT_POWER_ERR		926007010
#define DSM_SHB_ERR_MAG_I2C_READ		926007011
#define DSM_SHB_ERR_MAG_DATA_ABNORAML		926007012
#define DSM_SHB_ERR_MAG_DATA_NOT_UPDATE		926007013
#define DSM_SHB_ERR_MAG_SELFTEST_ERR		926007014
#define DSM_SHB_ERR_SENSORSERVICE_EXIT_ERR	926007015
#define DSM_SHB_ERR_SENSORSERVICE_DATA_UPDATE	926007016

/* key */
#define DSM_KEY_ERROR_NO			926003000
#define DSM_POWER_KEY_ERROR_NO			926003001
#define DSM_LONG_PRESS_POWER_KEY_ERROR_NO	926003002

/* hall */
#define DSM_HALL_ERROR_NO			926002000


/* camera flash */
#define DSM_FLASH_I2C_ERROR_NO			927002000
#define DSM_FLASH_OPEN_SHOTR_ERROR_NO		927002001
#define DSM_FLASH_HOT_DIE_ERROR_NO		927002002
#define DSM_FLASH_UNDER_VOLTAGE_LOCKOUT_ERROR_NO	927002003

/* project */
#define DSM_ITO_OUT_OF_RANGE_ERROR_NO		927011031

/* camera hal flash */
#define DSM_DALLAS_FLASH_SCHARGER_ERROR_NO	927003018

/* ext isp */
#define DSM_EXTISP_LOAD_FW_ERROR_NO		927007000
#define DSM_EXTISP_PQ_ERROR_NO			927007001
#define DSM_EXTISP_I2C_ERROR_NO			927007002
#define DSM_EXTISP_USPI_ERROR_NO		927007003
#define DSM_EXTISP_VCM_ERROR_NO			927007004
#define DSM_EXTISP_INTERRUPT_ERROR_NO		927007005
#define DSM_EXTISP_COMMONFUNC_ERROR_NO		927007006
#define DSM_EXTISP_A3_ERROR_NO			927007007
#define DSM_EXTISP_PIPE_ERROR_NO		927007008
#define DSM_EXTISP_RDN_ERROR_NO			927007009
#define DSM_EXTISP_TXLM_ERROR_NO		927007010
#define DSM_EXTISP_MTX_ERROR_NO			927007011
#define DSM_EXTISP_MRX_ERROR_NO			927007012
#define DSM_EXTISP_FEC0_ERROR_NO		927007013
#define DSM_EXTISP_SENSOR_ERROR_NO		927007014
#define DSM_EXTISP_FEC1_ERROR_NO		927007015
#define DSM_EXTISP_CAP_ERROR_NO			927007016
#define DSM_EXTISP_OTHER_ERROR_NO		927007017

/* camera csi */
#define DSM_CSI_MIPI0_ERROR_NO			927001000
#define DSM_CSI_MIPI1_ERROR_NO			927001001

/* camera qcom */
#define DSM_CAMERA_SOF_ERR			927009001
#define DSM_CAMERA_I2C_ERR			927009002
#define DSM_CAMERA_CHIP_ID_NOT_MATCH		927009003
#define DSM_CAMERA_OTP_ERR			927009004
#define DSM_CAMERA_SENSOR_NO_FRAME		927009005
#define DSM_CAMERA_LED_FLASH_CIRCUIT_ERR	927009006
#define DSM_CAMERA_LED_FLASH_OVER_TEMPERATURE	927009007
#define DSM_CAMERA_LED_FLASH_VOUT_ERROR		927009008
#define DSM_CAMERA_ISP_OVERFLOW			927009009
#define DSM_CAMERA_ISP_AXI_STREAM_FAIL		927009010
#define DSM_CAMERA_POST_EVENT_TIMEOUT		927009011
#define DSM_CAMERA_ACTUATOR_INIT_FAIL		927009012
#define DSM_CAMERA_ACTUATOR_SET_INFO_ERR	927009013
#define DSM_CAMERA_ACTUATOR_MOVE_FAIL		927009014
#define DSM_CAMERA_FD_LEAK_ERR			927009015
#define DSM_CAMERA_SENSOR_INIT_SESSION_FAIL	927009016
#define DSM_CAMERA_SESSION_ID_MATCH_FAIL	927009017
#define DSM_CAMERA_REPROCESS_PARAM_ERROR	927009018
#define DSM_CAMERA_MCT_PIPELINE_SET_FAIL	927009019
#define DSM_CAMERA_INVALID_POLL_FD		927009020
#define DSM_CAMERA_START_CHANNEL_NO_BUF		927009021
#define DSM_CAMERA_BUF_MANAGER_NO_BUF		927009022
#define DSM_CAMERA_ISP_REQUEST_HAL_BUF_FAIL	927009023
#define DSM_CAMERA_ISP_REQUEST_BUF_UPDATE_FAIL	927009024
#define DSM_CAMERA_CPP_INPUT_PARAMS_ERROR	927009025
#define DSM_CAMERA_CPP_OUTPUT_PARAMS_ERROR	927009026
#define DSM_CAMERA_ISPIF_PORT_ERROR		927009027
#define DSM_CAMERA_ISPIF_MODULE_NOT_FOUND	927009028
#define DSM_CAMERA_ISPIF_CFG_ERROR		927009029
#define DSM_CAMERA_FOCUS_NOT_DONE		927009030
#define DSM_CAMERA_OIS_ACC_FAIL			927009031
#define DSM_CAMERA_OIS_CHECK_FAIL		927009032
#define DSM_CAMERA_OIS_INIT_FAIL		927009033
#define DSM_CAMERA_OIS_VIBRATE_FAIL		927009034
#define DSM_CAMERA_SENSOR_INIT_FAIL		927009035
#define DSM_CAMERA_SENSOR_SET_RESOLUTION_FAIL	927009036
#define DSM_CAMERA_SENSOR_APPLY_EXPOSURE_FAIL	927009037
#define DSM_CAMERA_SENSOR_START_STOP_STREAM_FAIL	927009038
#define DSM_CAMERA_EEPROM_CALIBRATE_FAIL	927009039
#define DSM_CAMERA_VIDC_OVERLOADED		927009040
#define DSM_CAMERA_VIDC_SESSION_ERROR		927009041
#define DSM_CAMERA_VIDC_LOAD_FW_FAIL		927009042
#define DSM_CAMERA_OTP_I2C_ERR			927009043

/* camera pmic */
#define DSM_CAMPMIC_I2C_ERROR_NO		927010000
#define DSM_CAMPMIC_ENABLE_ERROR_NO		927010001
#define DSM_CAMPMIC_OVER_CURRENT_ERROR_NO	927010002
#define DSM_CAMPMIC_TSD_ERROR_NO		927010003
#define DSM_CAMPMIC_UNDER_VOLTAGE_ERROR_NO	927010004

/* ov isp */
#define DSM_ISP22_MCU_NO_RSP_ERROR_NO		927004000
#define DSM_ISP22_CMD_SET_ERROR_NO		927004001
#define DSM_ISP22_SENSOR_PRIMARY_ERROR_NO	927004002
#define DSM_ISP22_SENSOR_SECONDARY_ERROR_NO	927004003
#define DSM_ISP22_FLASH_ERROR_NO		927004004

/* ivp */
#define DSM_IVP_SMMU_ERROR_NO			927005000
#define DSM_IVP_WATCH_ERROR_NO			927005001
#define DSM_IVP_DWAXI_ERROR_NO			927005002
#define DSM_IVP_OPEN_ERROR_NO			927005003
#define DSM_IVP_MESSAGE_ERROR_NO		927005004
#define DSM_IVP_PANIC_ERROR_NO			927005005

/* isp */
#define DSM_SEC_ION_ERROR_NO			927012000

/* wifi */
#ifndef DSM_WIFI_MODULE_INIT_ERROR
#define DSM_WIFI_MODULE_INIT_ERROR		909030001
#endif

#define DSM_WIFI_KSO_ERROR			909030002
#define DSM_WIFI_CMD52_ERROR			909030003
#define DSM_WIFI_CMD53_ERROR			909030004
/* wifi open */
#define DSM_WIFI_SDIO_RESET_COMM_ERROR		909030005

#ifndef DSM_WIFI_SDIO_PROBE_ATTACH_ERROR
#define DSM_WIFI_SDIO_PROBE_ATTACH_ERROR	909030006
#endif
#ifndef DSM_WIFI_SDIO_FIRMWARE_DL_ERROR
#define DSM_WIFI_SDIO_FIRMWARE_DL_ERROR		909030007
#endif

#define DSM_WIFI_DHD_DEV_INIT_IOCTL_ERROR	909030008
/* wifi scan */
#define DSM_WIFI_WLC_SET_PASSIVE_SCAN_ERROR	909030009
#define DSM_WIFI_WLC_SCAN_ERROR			909030010
#define DSM_WIFI_WLC_SET_SCANSUPPRESS_ERROR	909030011
#define DSM_WIFI_WLC_GET_CHANNEL_ERROR		909030012
#define DSM_WIFI_WLC_SCAN_RESULTS_ERROR		909030013
/* wifi connect */
#define DSM_WIFI_WLC_DISASSOC_ERROR		909030014
#define DSM_WIFI_WLC_SET_SSID_ERROR		909030015
#define DSM_WIFI_SET_CIPHER_ERROR		909030016
#define DSM_WIFI_SET_KEY_MGMT_ERROR		909030017
#define DSM_WIFI_SET_SHAREDKEY_ERROR		909030018

#ifndef DSM_WIFI_OPEN_ERROR
#define DSM_WIFI_OPEN_ERROR			909030019
#endif
/* wifi tem ctrl */
#define DSM_WIFI_CHIPSET_DAMAGE_WARNING		909030020
#define DSM_WIFI_TEM_CTRL_EVENT			909030021
#define DSM_WIFI_PMIC_CHECK_EVENT		909030022
#define DSM_WIFI_OTP_CHECK			909030023
#define DSM_WIFI_PCIE_LINKDOWN			909030024

/* wpa dmd event */
#define DSM_CTRL_EVENT_ASSOC_REJECT		909030027
#define DSM_CTRL_EVENT_DISCONNECTED		909030028
#define DSM_CTRL_EVENT_AUTH_REJECT		909030029
#define DSM_CTRL_EVENT_EAP_FAILURE		909030030
#define DSM_CTRL_EVENT_CONNECT_FAILURE		909030031

/* wifi qcom */
#define DSM_WIFI_ERR				909030007
#define DSM_WIFI_FAIL_LOADFIRMWARE_ERR		909030007
#define DSM_WIFI_DRIVER_LOAD_ERR		909030019
#define DSM_WIFI_MAC_ERR			909031004
#define DSM_WIFI_ROOT_NOT_RIGHT_ERR		909031009
/* wifi sdio */
#define DSM_SDIO_TUNNING_ERR			909030037
#define DSM_SDIO_DATA_TIMEOUT			909030038
#define DSM_SDIO_CRC_ERR			909030039

#define DSM_WIFI_RESERVED			20701
/* recovery */
#define DSM_RECOVERY_ERROR_NO			924001000

/* selinux */
#define DSM_SELINUX_ERROR_NO			924002000

/* modem spi */
#define DSM_SPI_WRITE_ACK_ERROR_NO		926009000
#define DSM_SPI_READ_ACK_ERROR_NO		(DSM_SPI_WRITE_ACK_ERROR_NO + 1)
#define DSM_SPI_80_ACK_ERROR_NO			(DSM_SPI_WRITE_ACK_ERROR_NO + 2)
#define DSM_SPI_SYNC_ERROR_NO			(DSM_SPI_WRITE_ACK_ERROR_NO + 3)
#define DSM_SPI_DOWN_ERROR_NO			(DSM_SPI_WRITE_ACK_ERROR_NO + 4)
#define DSM_SPI_PORT_BUSY_NO			(DSM_SPI_WRITE_ACK_ERROR_NO + 5)
#define DSM_SPI_DATA_READ_ERROR_NO		(DSM_SPI_WRITE_ACK_ERROR_NO + 6)
#define DSM_SPI_DATA_DROP_NO			(DSM_SPI_WRITE_ACK_ERROR_NO + 7)
#define DSM_SPI_AUTO_READY_ERROR_NO		(DSM_SPI_WRITE_ACK_ERROR_NO + 8)
#define DSM_SPI_KZALLOC_FAILED_NO		(DSM_SPI_WRITE_ACK_ERROR_NO + 9)
#define DSM_SPI_ALLOC_SKB_FAILED_NO		(DSM_SPI_WRITE_ACK_ERROR_NO + 10)
#define DSM_SPI_DOWN_RETRY_MAX_NO		(DSM_SPI_WRITE_ACK_ERROR_NO + 11)
#define DSM_SPI_SYNC_ERR_MAX_NO			(DSM_SPI_WRITE_ACK_ERROR_NO + 12)
#define DSM_APCP_SDIO_WRITE_ACK_ERROR_NO	(DSM_SPI_WRITE_ACK_ERROR_NO + 13)

/* spi */
/* spi_sync timeout error */
#define DSM_SPI_ERROR_NO			925001000
#define DSM_SPI_INVALID_ARGUMENT_ERR_NO		925001001
#define DSM_SPI_SHUTDOWN_ERR_NO			925001002
#define DSM_SPI_UNKOWN_ERR_NO			925001003
#define DSM_SPI_SG_ALLOC_RX_PAGE_INVILAD_LEN	925001004
#define DSM_SPI_SG_ALLOC_TX_PAGE_INVILAD_LEN	925001005
#define DSM_SPI_RX_FIFO_NOT_EMPTY		925001006
#define DSM_SPI_SPI_IS_BUSY			925001007
/* fs & ext4 */
#define DSM_FS_EXT4_ERROR			928003000
#define DSM_FS_EXT4_ERROR_INODE			928003001
#define DSM_FS_EXT4_ERROR_FILE			928003002
#define DSM_FS_EXT4_ERROR_READ_SUPER		928003003
#define DSM_FS_EXT4_ERROR_READ_SUPER_SECOND	928003004
#define DSM_FS_EXT4_ERROR_WRITE_SUPER		928003005
/* hmfs */
#ifndef DSM_HMFS_NEED_FSCK
#define DSM_HMFS_NEED_FSCK			928005101
#endif
#ifndef DSM_HMFS_SET_SBI_NEED_FSCK
#define DSM_HMFS_SET_SBI_NEED_FSCK		928005102
#endif
/* f2fs */
#ifndef DSM_F2FS_UNLINK_SIGNIF_FILE
#define DSM_F2FS_UNLINK_SIGNIF_FILE		928005000
#endif
#ifndef DSM_F2FS_NEED_FSCK
#define DSM_F2FS_NEED_FSCK			928005001
#endif
#ifndef DSM_IOCACHE_ERROR
#define DSM_IOCACHE_ERROR			928005002
#endif
#ifndef DSM_F2FS_SET_SBI_NEED_FSCK
#define DSM_F2FS_SET_SBI_NEED_FSCK		928005004
#endif
#define DSM_UART_OPEN_HWINIT_ERROR		22100
#define DSM_UART_OPEN_IRQ_REQUSET_FAILED	(DSM_UART_OPEN_HWINIT_ERROR + 1)
#define DSM_UART_TX_DMA_MAP_FAILED		(DSM_UART_OPEN_HWINIT_ERROR + 2)
#define DSM_UART_TX_DMA_BUSY_ERROR		(DSM_UART_OPEN_HWINIT_ERROR + 3)
#define DSM_UART_RX_DMA_READ_BUFFER_FULL_ERROR	(DSM_UART_OPEN_HWINIT_ERROR + 4)
#define DSM_UART_CONTROLLER_FIFO_OVERRUN_ERROR	(DSM_UART_OPEN_HWINIT_ERROR + 5)
#define DSM_UART_CONTROLLER_LINE_BREAK_ERROR	(DSM_UART_OPEN_HWINIT_ERROR + 6)
#define DSM_UART_CONTROLLER_PARITY_ERROR	(DSM_UART_OPEN_HWINIT_ERROR + 7)
#define DSM_UART_CONTROLLER_FRAME_ERROR		(DSM_UART_OPEN_HWINIT_ERROR + 8)

/* stat mm */
#define DSM_MM_STAT					924003000
/* nfc */
#define DSM_NFC_I2C_WRITE_ERROR_NO			923002000
#define DSM_NFC_I2C_READ_ERROR_NO			923002001
#define DSM_NFC_CLK_ENABLE_ERROR_NO			923002002
#define DSM_NFC_I2C_WRITE_EOPNOTSUPP_ERROR_NO		923002003
#define DSM_NFC_I2C_READ_EOPNOTSUPP_ERROR_NO		923002004
#define DSM_NFC_I2C_WRITE_EREMOTEIO_ERROR_NO		923002005
#define DSM_NFC_I2C_READ_EREMOTEIO_ERROR_NO		923002006
#define DSM_NFC_RD_I2C_WRITE_ERROR_NO			923002007
#define DSM_NFC_RD_I2C_READ_ERROR_NO			923002008
#define DSM_NFC_RD_I2C_WRITE_EOPNOTSUPP_ERROR_NO	923002009
#define DSM_NFC_RD_I2C_READ_EOPNOTSUPP_ERROR_NO		923002010
#define DSM_NFC_RD_I2C_WRITE_EREMOTEIO_ERROR_NO		923002011
#define DSM_NFC_RD_I2C_READ_EREMOTEIO_ERROR_NO		923002012
#define DSM_NFC_SIM_CHECK_ERROR_NO			923002013
#define DSM_NFC_HAL_CORE_RESET				923002014
#define DSM_NFC_HISEE_COS_IMAGE_UPGRADE_ERROR_NO	923002015
#define DSM_NFC_HISEE_POWER_ON_OFF_ERROR_NO		923002016
#define DSM_NFC_HISEE_APDU_COMMAND_OPERATION_ERROR_NO	923002017
/* irda */
#define DSM_IRDA_SEPARATED_ERROR_NO			923002018

/* hisee */
#define DSM_HISEE_BASE_ERROR_NO				925003000
#define DSM_HISEE_COS_IMAGE_UPGRADE_ERROR_NO	(DSM_HISEE_BASE_ERROR_NO)
#define DSM_HISEE_POWER_ON_OFF_ERROR_NO		(DSM_HISEE_BASE_ERROR_NO + 1)
#define DSM_HISEE_APDU_COMMAND_OPERATION_ERROR_NO (DSM_HISEE_BASE_ERROR_NO + 2)
/* fingerprint */
#define DSM_FINGERPRINT_WAIT_FOR_FINGER_ERROR_NO	912001000
#define DSM_FINGERPRINT_CAPTURE_IMAGE_ERROR_NO		912001001
#define DSM_FINGERPRINT_IDENTIFY_ERROR_NO		912001002
#define DSM_FINGERPRINT_TEST_DEADPIXELS_ERROR_NO	912001003
#define DSM_FINGERPRINT_ENROLL_ERROR_NO			912001004
#define DSM_FINGERPRINT_REMOVE_TEMPLATE_ERROR_NO	912001005
#define DSM_FINGERPRINT_ENUMERATE_ERROR_NO		912001006
#define DSM_FINGERPRINT_MODULE_OPEN_ERROR_NO		912001007
#define DSM_FINGERPRINT_PROBE_FAIL_ERROR_NO		912001008
#define DSM_FINGERPRINT_DIFF_DEADPIXELS_ERROR_NO	912001009
#define DSM_FINGERPRINT_MANY_DEADPIXELS_ERROR_NO	912001010
#define DSM_FINGERPRINT_DB_FILE_LOST_ERROR_NO		912001011
#define DSM_FINGERPRINT_BTB_DISCONNECT_ERROR_NO         926008000

/* usb 920004100~920004199 */
#define DSM_USB_XHCI_CMD_TIMEOUT                920004100
#define DSM_USB_RECORD_ABNORMAL_DEVICE          920004101
#define DSM_USB_AP_USE_HIFIUSB_ENUM_TIMEOUT     920004102
#define DSM_USB_TYPEC_BTB_CHECK                 920004103

/* pd 920004200~920004299 */
#define DSM_PD_TYPEC_VBUS_VALID			920004200
#define DSM_PD_TYPEC_VBUS_STILL_VALID		920004201

/* thp */
#define DMDE_SHB_THP_TASK_TIMEOUT               926004100
#define DMDE_SHB_THP_STATE_FAULT                926004101
#define DMDE_SHB_THP_AFE_DRIVER_NULL            926004102
#define DMDE_SHB_THP_AFE_START                  926004103
#define DMDW_SHB_THP_AFE_FRAME_NULL             926004104
#define DMDW_SHB_THP_AFE_RESTART                926004105
#define DMDI_SHB_THP_AFE_EXP1                   926004106
#define DMDI_SHB_THP_AFE_EXP2                   926004107
#define DMDI_SHB_THP_HARDWARE_RAW_JUMP          926004108
#define DMDI_SHB_THP_TSA_RAW_OVER_LIMIT         926004109
#define DMDI_SHB_THP_TSA_RECAL                  926004110
#define DMDI_SHB_THP_TSA_IDLE_EXIT              926004111
#define DMDI_SHB_THP_TSA_THENAR_LONG_PRESS      926004112
#define DMDI_SHB_THP_TSA_ALGO_EXP               926004113
#define DMDI_SHB_THP_TSA_ALGO_EXP1              926004114
#define DMDI_SHB_THP_TSA_SIDE_TOUCH             926004115
#define DMDI_SHB_THP_TSA_HOPPING_RAWJUMP        926004116
#define DMDI_SHB_THP_TSA_LINE_DATA_RAWJUMP      926004117
#define DMDI_SHB_THP_TSA_SIDETOUCH_EXP1         926004118
#define DMDI_SHB_THP_TSA_SIDETOUCH_EXP2         926004119

/* vibrator */
#define DSM_VIBRATOR_FPC_CHECK_NO		926012000
#define DSM_PMIC_VIBRATOR_IRQ_OCP_NO		926012001
#define DSM_PMIC_VIBRATOR_IRQ_OUT_NO		926012002
#define DSM_PMIC_VIBRATOR_IRQ_UNDERVOL_NO	926012003
#define DSM_PMIC_VIBRATOR_IRQ_OVERVOL_NO	926012004
#define DSM_PMIC_VIBRATOR_IRQ_ADC_NO		926012005
#define DSM_PMIC_VIBRATOR_FREQ_CHECK_NO		926012006
#define DSM_VIBRATOR_POPUP_ERROR                926012008
#define DSM_VIBRATOR_CALL_IN_ERROR              926012009
#define DSM_VIBRATOR_POPUP_TEN_ERROR            926012010
#define DSM_VIBRATOR_CALL_IN_TEN_ERROR          926012011
#define DSM_VIBRATOR_FREQ_OPERATE_ERROR         926012012
#define DSM_VIBRATOR_GS_I2C_ERROR               926012013
#define DSM_VIBRATOR_GC_FAILURE                 926012014

/* sensorhub vibrator */
#define DSM_SHB_VIBRATOR_ABNORMAL_ERROR         926012015
#define DSM_SHB_VIBRATOR_OCP_ERROR              926012016
#define DSM_SHB_VIBRATOR_UVP_ERROR              926012017
#define DSM_SHB_VIBRATOR_OVP_ERROR              926012018
#define DSM_SHB_VIBRATOR_OTP_ERROR              926012019
#define DSM_SHB_VIBRATOR_F0_ERROR               926012020

/* camera DF fpga */
#define DSM_FPGA_LOAD_FW_FAIL			927011000
#define DSM_FPGA_SPI_RW_FAIL			927011001
#define DSM_FPGA_SELT_TEST_FAIL			927011002
#define DSM_FPGA_PROJ_OVER_CURRENT		927011003
#define DSM_FPGA_ILLU_OVER_CURRENT		927011004
#define DSM_FPGA_PROJ_PLUS_TOO_LONG		927011005
#define DSM_FPGA_ILLU_PLUS_TOO_LONG		927011006
#define DSM_FPGA_PROJ_FREQU_OVER_LIMIT		927011007
#define DSM_FPGA_ILLU_FREQU_OVER_LIMIT          927011008
#define DSM_FPGA_AGEING_PROJ_FREQU_LIMIT        927011009
#define DSM_FPGA_AGEING_ILLU_FREQU_LIMIT        927011010
#define DSM_FPGA_OTHER_FAIL                     927011011

/* DMD NUMBER FOR TP AND SENSOR BEGIN */
#define CLIENT_DSM_KEY				"dsm_key"
#define DSM_GS_I2C_ERROR			926007000
#define DSM_GS_DATA_ERROR			926007001
#define DSM_GS_XYZ_0_ERROR			926007002
#define DSM_GS_DATA_TIMES_NOTCHANGE_ERROR	926007003
#define DSM_LPS_I2C_ERROR			926007004
#define DSM_LPS_WRONG_IRQ_ERROR			926007005
#define DSM_LPS_THRESHOLD_ERROR			926007006
#define DSM_LPS_ENABLED_IRQ_ERROR		926007007
#define DSM_LPS_ENABLED_ERROR			926007008
#define DSM_LPS_THRESHOLD_SIZE_ERROR		926007009
#define DSM_LPS_INSTANT_POWER_OFF_ERROR		926007010
#define DSM_MS_I2C_ERROR			926007011
#define DSM_MS_DATA_ERROR			926007012
#define DSM_MS_DATA_TIMES_NOTCHANGE_ERROR	926007013
#define DSM_MS_SELF_TEST_ERROR			926007014
#define DSM_SENSOR_SERVICE_EXIT			926007015
#define DSM_SENSOR_SERVICE_NODATA		926007016
#define DSM_HS_IRQ_TIMES_ERR			926002001
#define DSM_HS_IRQ_INTERVAL_ERR			926002002
#define DSM_VOL_KEY_PRESS_TIMES_ERR		926003003
#define DSM_VOL_KEY_PRESS_INTERVAL_ERR		926003004
#define DSM_POWER_KEY_PRESS_TIMES_ERR		926003005
#define DSM_POWER_KEY_PRESS_INTERVAL_ERR	926003006
#define DSM_TOUCHKEY_PROBE_I2C_ERR		926003007
#define DSM_TOUCHKEY_HANDLER_I2C_ERR		926003008
#define DSM_TOUCHKEY_FW_UPDATE_ERR		926003009
#define DSM_TOUCHKEY_WAKE_UP_ERR		926003010

enum DSM_KEYS_TYPE {
	DSM_VOL_KEY = 0,
	DSM_VOL_UP_KEY,
	DSM_VOL_DOWN_KEY,
	DSM_POW_KEY,
	DSM_HALL_IRQ,
};

#define DSM_POWER_KEY_VAL			116
#define DSM_VOL_DOWN_KEY_VAL			114
#define DSM_SENSOR_BUF_MAX			2048
#define DSM_SENSOR_BUF_COM			2048

/* DMD NUMBER FOR AUDIO BEGIN */
#define DSM_AUDIO_ERROR_NUM			921001012
#define DSM_AUDIO_HANDSET_DECT_FAIL_ERROR_NO	(DSM_AUDIO_ERROR_NUM)
#define DSM_AUDIO_ADSP_SETUP_FAIL_ERROR_NO	(DSM_AUDIO_ERROR_NUM + 1)
#define DSM_AUDIO_CARD_LOAD_FAIL_ERROR_NO	(DSM_AUDIO_ERROR_NUM + 2)
#define DSM_AUDIO_HAL_FAIL_ERROR_NO		(DSM_AUDIO_ERROR_NUM + 3)
#define DSM_AUDIO_MODEM_CRASH_ERROR_NO		(DSM_AUDIO_ERROR_NUM + 4)
#define DSM_AUDIO_HANDSET_PLUG_PRESS_ERROR	(DSM_AUDIO_ERROR_NUM + 5)
#define DSM_AUDIO_HANDSET_PRESS_RELEASE_ERROR	(DSM_AUDIO_ERROR_NUM + 6)
#define DSM_AUDIO_HANDSET_PLUG_RELEASE_ERROR	(DSM_AUDIO_ERROR_NUM + 7)
#define DSM_AUDIO_MMI_TEST_TIME_TOO_SHORT	(DSM_AUDIO_ERROR_NUM + 8)
#define DSM_AUDIO_CFG_CODEC_CLK_FAIL_ERROR	(DSM_AUDIO_ERROR_NUM + 9)
#define DSM_AUDIO_MODEM_CRASH_CODEC_CALLBACK	(DSM_AUDIO_ERROR_NUM + 10)
#define DSM_AUDIO_CODEC_RESUME_FAIL_ERROR	(DSM_AUDIO_ERROR_NUM + 11)
/* (DSM_AUDIO_ERROR_NUM + 12) has been occupied by asd test */
#define DSM_AUDIO_VRM_ERROR			(DSM_AUDIO_ERROR_NUM + 21)

/* DM */
#define DSM_DM_VERITY_ERROR_NO			928001000
#define DSM_DM_VERITY_FEC_INFO_NO		928001001
#define DSM_DM_VERITY_CE_ERROR_NO		928001002
/* cpu_buck */
#define ERROR_NO_CPU_BUCK_BASE			920012000

#ifdef CONFIG_HUAWEI_DATA_ACQUISITION
#define DA_SENSOR_HUB_ERROR_NO			924005001
#define DA_VIBRATOR_ERROR_NO			924005002
#define DA_BATTERY_ACR_ERROR_NO			924005003
#define DA_LCD_AVDD_ERROR_NO			924005004
#endif

/* DMD NUMBER FOR RTC BEGIN */
#define DSM_RTC_PMU_READCOUNT_ERROR_NO		925005000
#define DSM_RTC_SET_RTC_TMIE_WARNING_NO		925005001

struct dsm_client_ops {
	int (*poll_state)(void);
	int (*dump_func)(int type, void *buff, int size);
};

struct dsm_dev {
	const char *name;
	const char *device_name;
	const char *ic_name;
	const char *module_name;
	struct dsm_client_ops *fops;
	size_t buff_size;
};

struct dsm_client {
	char client_name[CLIENT_NAME_LEN];
	char device_name[DSM_MAX_DEVICE_NAME_LEN];
	char ic_name[DSM_MAX_IC_NAME_LEN];
	char module_name[DSM_MAX_MODULE_NAME_LEN];
	int client_id;
	int error_no;
	unsigned long buff_flag;
	struct dsm_client_ops *cops;
	wait_queue_head_t waitq;
	size_t read_size;
	size_t used_size;
	size_t buff_size;
	u8 dump_buff[];
};

/* for userspace client, such as sensor service, please refer to it */

struct dsm_extern_client {
	char client_name[CLIENT_NAME_LEN];
	int buf_size;
};

#ifdef CONFIG_HUAWEI_DATA_ACQUISITION
#define MAX_BSN_LEN		20
#define MAX_STATION_LEN		8
#define MAX_DEVICE_NAME_LEN	32
#define MAX_TEST_NAME_LEN	32
#define MAX_VAL_LEN		64
#define MAX_RESULT_LEN		8
#define MAX_TIME_LEN		20
#define MAX_FIRMWARE_LEN	32
#define MAX_DESCRIPTION_LEN	512
#define MAX_FRONT_ITEM_LEN 32
#define MAX_ITEM_COUNTER_LEN 16
#define MAX_ENVIRONMENT_LEN 128
#define MAX_MSG_EVENT_NUM	4
#define DATA_FROM_KERNEL	1
#define ITEM_ID_MIN		700000000
#define ITEM_ID_MAX		799999999
#define DA_MIN_ERROR_NO		924005000
#define DA_MAX_ERROR_NO		924005999

struct event {
	int error_code;				/* error code (errno) */
	int item_id;				/* index of test item */
	int cycle;				/* which round in aging test */
	char result[MAX_RESULT_LEN];		/* actual test result */
	char station[MAX_STATION_LEN];		/* name of station */
	char bsn[MAX_BSN_LEN];			/* serial number of board */
	char time[MAX_TIME_LEN];		/* test time */
	char device_name[MAX_DEVICE_NAME_LEN];	/* name of device */
	char test_name[MAX_TEST_NAME_LEN];	/* name of test item */
	char value[MAX_VAL_LEN];		/* measured value */
	char min_threshold[MAX_VAL_LEN];	/* min limit of measured value */
	char max_threshold[MAX_VAL_LEN];	/* max limit of measured value */
	char firmware[MAX_FIRMWARE_LEN];	/* firmware information */
	char description[MAX_DESCRIPTION_LEN];	/* brief description */
	char front_item[MAX_FRONT_ITEM_LEN];
	char item_counter[MAX_ITEM_COUNTER_LEN];
	char environment[MAX_ENVIRONMENT_LEN];
};

struct message {
	int version;				/* message version */
	int data_source;			/* where is data from? */
	int num_events;				/* event counts */
	struct event events[MAX_MSG_EVENT_NUM];	/* store event entity */
};
#endif

#ifdef CONFIG_HUAWEI_DSM
struct dsm_client *dsm_register_client(struct dsm_dev *dev);
void dsm_unregister_client(struct dsm_client *dsm_client, struct dsm_dev *dev);
struct dsm_client *dsm_find_client(char *dsm_name);
int dsm_client_ocuppy(struct dsm_client *client);
int dsm_client_unocuppy(struct dsm_client *client);
int dsm_client_record(struct dsm_client *client, const char *fmt, ...);
int dsm_client_copy(struct dsm_client *client, void *src, int sz);

#ifdef CONFIG_HUAWEI_DATA_ACQUISITION
int dsm_client_copy_ext(struct dsm_client *client, const void *src, int sz);
#endif

void dsm_client_notify(struct dsm_client *client, int error_no);
extern void dsm_key_pressed(int type);
int dsm_update_client_vendor_info(struct dsm_dev *dev);

#else
static inline struct dsm_client *dsm_register_client(struct dsm_dev *dev)
{
	return NULL;
}

static inline struct dsm_client *dsm_find_client(char *dsm_name)
{
	return NULL;
}

static inline int dsm_client_ocuppy(struct dsm_client *client)
{
	return 1;
}

static inline int dsm_client_unocuppy(struct dsm_client *client)
{
	return 0;
}

static inline int dsm_client_record(struct dsm_client *client,
				    const char *fmt, ...)
{
	return 0;
}

static inline int dsm_client_copy(struct dsm_client *client, void *src, int sz)
{
	return 0;
}

#ifdef CONFIG_HUAWEI_DATA_ACQUISITION
static inline int dsm_client_copy_ext(struct dsm_client *client,
				      void *src, int sz)
{
	return 0;
}
#endif

static inline void dsm_client_notify(struct dsm_client *client, int error_no)
{

}

static inline int dsm_update_client_vendor_info(struct dsm_dev *dev)
{
	return 0;
}
#endif

#endif
