/*
 * Copyright (c) CompanyNameMagicTag 2021. All rights reserved.
 * Description: Bl31 SMC header files
 * Author : AuthorNameMagicTag
 * Create : 2021/4/10
 */

#ifndef BL31_COMMON_SMC_H
#define BL31_COMMON_SMC_H

/* Get the group number of FID */
#define FID_BL31_USE(x)	        (((x) & 0xff00) >> 8)

/* The base of OEM Service */
#define SMC_OEM_BASE            0xc3u

/* Module Group Number Define */
#define FID_LOG_GROUP           0x01
#define FID_HIBERNATE_GROUP     0x02
#define FID_UEFI_GROUP          0x03
#define FID_TEE_MEM_GROUP       0x06
#define FID_FIQSET_GROUP        0x07
#define FID_TEE_TZASC_GROUP     0x08

#define FID_BL31_MAXGROUP 0x0f

/* Get FID from group and id */
#define MAKE_FID(group, id)    ((((SMC_OEM_BASE << 16) + group) << 8) + id)

/* 0xc3000100 to 0xc30001ff for bl31 log */
#define BL31_MNTN_LOG_READ        MAKE_FID(FID_LOG_GROUP, 0x00)
#define BL31_MNTN_INFO            MAKE_FID(FID_LOG_GROUP, 0x02)
#define BL31_MNTN_TRACE           MAKE_FID(FID_LOG_GROUP, 0x03)

/* 0xc3000200 to 0xc30002ff for S4(Suspend to Disk) */
#define BL31_HIBERNATE_FREEZE     MAKE_FID(FID_HIBERNATE_GROUP, 0x00)
#define BL31_HIBERNATE_RESTORE    MAKE_FID(FID_HIBERNATE_GROUP, 0x01)
#define BL31_HIBERNATE_TEST       MAKE_FID(FID_HIBERNATE_GROUP, 0x02)

/* 0xc3000300 to 0xc30003ff for PC-UEFI/KERNEL */
#define KERNEL_SATA_HDD_UNSIGN1   MAKE_FID(FID_UEFI_GROUP, 0x06)
#define KERNEL_SATA_HDD_UNSIGN2   MAKE_FID(FID_UEFI_GROUP, 0x07)
#define KERNEL_NVME_SSD_UNSIGN    MAKE_FID(FID_UEFI_GROUP, 0x08)

#define SMMUPT_S4_ENCRYPT_AND_COPY MAKE_FID(FID_TEE_MEM_GROUP, 0x00)
#define SMMUPT_S4_DECRYPT_AND_COPY MAKE_FID(FID_TEE_MEM_GROUP, 0x01)

/* 0xc3000800 to 0xc30008ff for tzacs */
#define TEE_MEM_SMC_TZASC          MAKE_FID(FID_TEE_TZASC_GROUP, 0x00)

#define BL31_FIQSET_WATCHDOG      MAKE_FID(FID_FIQSET_GROUP, 0x00)
#define BL31_FIQSET_SGI           MAKE_FID(FID_FIQSET_GROUP, 0x01)
/* Declare BL31 panic function here */
void ipi_mntn_bl31_handle(void);

#endif /* BL31_COMMON_SMC_H */
