/*
 * Copyright (c) CompanyNameMagicTag 2019-2021. All rights reserved.
 * Description: lpmuc ram config
 */

#ifndef __LPMCU_RAM_CONFIG_H__
#define __LPMCU_RAM_CONFIG_H__

/*
 * [0x0000 ~ 0xcfff]  lpmcu_code 52k
 * [0xd000 ~ 0xd408]  lpmcu bbox log
 * [0xdf00 ~ 0xdfff]  bbox_param: magic reboot reason
 * [0xe000 ~ 0xe2ff]  suspend_param 0.75k
 * [0xe300 ~ 0xe3ff]  boot stanby param 0.25k
 * [0xe400 ~ 0xe5ff]  wakeup_param 0.5k
 * [0xe600 ~ 0xfeff]  xdata 6.25k
 * [0xff00 ~ 0xff0b]  emei 2g3
 * [0xff0c ~ 0xff8b]  reserved
 * [0xff8c ~ 0xff9b]  hdmirx param
 * [0xff9c ~ 0xfffb]  gpio pwm
 * [0xfffc ~ 0xffff]  rokid: reboot reason
 */

#define LPMCU_RAM_BASE 0x800000
#define LPMCU_SIZE 0x10000 /* 64k */
#define LPMCU_CODE_MAXSIZE 0xd000

/* bbox log address space, 0xd000 ~ 0xd408 */
#define LPMCU_LOG_FLAG_ADDR 0xd000
#define LPMCU_LOG_SIZE_ADDR (LPMCU_LOG_FLAG_ADDR + 4)
#define LPMCU_LOG_ADDR (LPMCU_LOG_FLAG_ADDR + 8)
#define LPMCU_LOG_DATA_SIZE 0x400
#define LPMCU_LOG_TOTLE_SIZE (LPMCU_LOG_DATA_SIZE + 8)

#define LPMCU_LOG_WRITE_FLAG 0x5a5a5a5a

/* bbox param address space, 0xdf00 ~ 0xdfff */
#define LPMCU_BBOX_FLAG_ADDR 0xdf00
#define LPMCU_BBOX_BOOT_REASON_ADDR (LPMCU_BBOX_FLAG_ADDR + 4)
#define LPMCU_BBOX_BOOT_SUBTYPE_ADDR (LPMCU_BBOX_BOOT_REASON_ADDR + 4)
#define LPMCU_BBOX_KEYPOINT_ADDR (LPMCU_BBOX_BOOT_SUBTYPE_ADDR + 4)
#define LPMCU_BBOX_REBOOT_TIME_ADDR (LPMCU_BBOX_KEYPOINT_ADDR + 24)
#define LPMCU_BBOX_END_ADDR 0xdf40

/* suspend param address space, 0xe000 ~ 0xe2ff */
#define LPMCU_STANDBY_DATA_ADDR 0xe000
#define LPMCU_STANDBY_DATA_SIZE 0x300

#define LPMCU_CHIP_NAME_ID_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x0)
#define LPMCU_CHIP_REVERSION_ADDR (LPMCU_CHIP_NAME_ID_ADDR + 0x4)

#define LPMCU_KEYLED_SUSPEND_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x8)
#define LPMCU_KEYLED_TYPE_ADDR (LPMCU_KEYLED_SUSPEND_PARAM_ADDR + 0x4)
#define LPMCU_KEYLED_WAKEUP_KEY_ADDR (LPMCU_KEYLED_TYPE_ADDR + 0x4)
#define LPMCU_KEYLED_DISPLAY_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x14)
#define LPMCU_KEYLED_DISPLAY_VALUE_ADDR (LPMCU_KEYLED_DISPLAY_ADDR + 0x4)

#define LPMCU_GPIO_SUSPEND_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x1C)
#define LPMCU_GPIO_SUSPEND_PARAM0_ADDR (LPMCU_GPIO_SUSPEND_PARAM_ADDR + 0x4)
#define LPMCU_GPIO_POWEROFF_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x40)
#define LPMCU_GPIO_POWEROFF_PARAM0_ADDR (LPMCU_GPIO_POWEROFF_PARAM_ADDR + 0x4)

#define LPMCU_GPIO_POWERCTRL_DDR_PARAM_ADDR (LPMCU_GPIO_POWEROFF_PARAM_ADDR + 0x20)

#define LPMCU_ETH_SUSPEND_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x64)
#define LPMCU_ETH_TO_PASSIVE_STANDBY_ADDR (LPMCU_ETH_SUSPEND_PARAM_ADDR + 0x4)

#define LPMCU_TIMEOUT_SUSPEND_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x6C)
#define LPMCU_TIMEOUT_SUSPEND_TIME_ADDR (LPMCU_TIMEOUT_SUSPEND_PARAM_ADDR + 0x4)
#define LPMCU_DBG_MASK_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x74)
#define LPMCU_RESUME_RESET_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x74)

#define LPMCU_HDMI_SUSPEND_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x78)
#define LPMCU_HDMIRX_PLUGIN_PORT_ADDR (LPMCU_HDMI_SUSPEND_PARAM_ADDR + 0x4)
#define LPMCU_HDMITX_CEC_PARAM_ADDR (LPMCU_HDMI_SUSPEND_PARAM_ADDR + 0x8)

#define LPMCU_IR_SUSPEND_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x98)
#define LPMCU_IR_LOW_VALUE_ADDR (LPMCU_IR_SUSPEND_PARAM_ADDR + 0x4)
#define LPMCU_IR_HIGH_VALUE_ADDR (LPMCU_IR_SUSPEND_PARAM_ADDR + 0x8)

#define LPMCU_LSADC_SUSPEND_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x114)
#define LPMCU_LSADC_KEY_ADDR (LPMCU_LSADC_SUSPEND_PARAM_ADDR + 0x4)

#define LPMCU_UART_SUSPEND_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x128)
#define LPMCU_USB_SUSPEND_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x12C)
#define LPMCU_STANDBY_LED_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x130)
#define LPMCU_BREATH_LED_PARAM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x134)
#define LPMCU_BREATH_CYCLE_ADDR (LPMCU_BREATH_LED_PARAM_ADDR + 0x4)

#define LPMCU_CUSTOM_MSG_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x140)
#define LPMCU_GPIO_AON_GROUP_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x190)
#define LPMCU_REG_MUTE_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x194)
#define LPMCU_MUTE_WAKEUP_ENABLE_VALUE (LPMCU_STANDBY_DATA_ADDR + 0x198)
#define LPMCU_MUTE_WAKEUP_DISABLE_VALUE (LPMCU_STANDBY_DATA_ADDR + 0x19c)
#define LPMCU_VOICE_WAKEUP_ENABLE_VALUE (LPMCU_STANDBY_DATA_ADDR + 0x1a0)
#define LPMCU_VGA_WAKEUP_ENABLE_VALUE (LPMCU_STANDBY_DATA_ADDR + 0x1a4)

#define LPMCU_S3_S4_GPIO_NUM_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x1a8)
#define LPMCU_S3_S4_GPIO_PARAM_ADDR (LPMCU_S3_S4_GPIO_NUM_ADDR + 0x4)

#define LPMCU_PRODUCT_FLAG_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x1bc)

#define LPMCU_MCU_SUSPEND_STATE_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x1c0)

/* set flag for entering standby in boot, 0xe300 ~ 0xe3ff */
#define LPMCU_BOOT_STANDBY_FLAG_ADDR 0xe300
#define LPMCU_CODE_LOAD_FLAG_ADDR (LPMCU_BOOT_STANDBY_FLAG_ADDR + 0x0) /* LPMCU代码加载标志位地址 */
#define LPMCU_START_IN_BOOT_ADDR (LPMCU_BOOT_STANDBY_FLAG_ADDR + 0x4) /* BOOT下启动LPMCU标志位地址 */
#define LPMCU_ENTER_SUSPEND_IN_BOOT_ADDR (LPMCU_BOOT_STANDBY_FLAG_ADDR + 0x8) /* BOOT下进入待机标志位地址 */
#define LPMCU_HOT_BOOT_ADDR (LPMCU_BOOT_STANDBY_FLAG_ADDR + 0xC) /* 热启动标志位地址 */

/* wakeup param address space, 0xe400 ~ 0xe5ff */
#define LPMCU_WAKEUP_DATA_ADDR (LPMCU_STANDBY_DATA_ADDR + 0x400)
#define LPMCU_WAKEUP_DATA_SIZE 0x200

#define LPMCU_WAKEUP_TYPE (LPMCU_WAKEUP_DATA_ADDR + 0x0)
#define LPMCU_WAKEUP_GPIO (LPMCU_WAKEUP_DATA_ADDR + 0x04)
#define LPMCU_WAKEUP_IR_KEYLOW (LPMCU_WAKEUP_DATA_ADDR + 0x8)
#define LPMCU_WAKEUP_IR_KEYHIGH (LPMCU_WAKEUP_DATA_ADDR + 0xC)
#define LPMCU_STANDBY_PERIOD (LPMCU_WAKEUP_DATA_ADDR + 0x10)
#define LPMCU_WAKEUP_LSADC_PARAM (LPMCU_WAKEUP_DATA_ADDR + 0x14)
#define LPMCU_REG_MUTE (LPMCU_WAKEUP_DATA_ADDR + 0x18)
#define LPMCU_S3_S4_FLAG_ADDR (LPMCU_WAKEUP_DATA_ADDR + 0x1c)


/* hdmirx param address space, 0xff8c ~ 0xff9b */
#define LPMCU_HDMIRX_WAKEUP_BASE_ADDR 0xff8c
#define LPMCU_HDMIRX_CEC_ADDR  0xff94
#define LPMCU_HDMIRX_CTRL_ADDR 0xff98

#define S3_S4_ENTER_LPMCU_FLAG 0x80510304
#define S3_S4_OPERATION_NUM 2

#define LPMCU_CODE_LOAD_FLAG        0x5A5AA5A5 /* LPMCU代码已加载标志 */
#define LPMCU_START_IN_BOOT_FLAG    0x5A5AA5A5 /* BOOT下LPMCU已启动标志 */
#define TEMP_CHECK_TO_SUSPEND 0x11111111

#define LPMCU_WAKEUP_GPIO_MAXNUM 4
#define LPMCU_WAKEUP_IRKEY_MAXNUM 10
#define LPMCU_POWEROFF_GPIO_MAXNUM 4
#define LPMCU_STATE_GPIO_MAXNUM 4
#define LPMCU_WAKEUP_HDMITX_ID_MAXNUM 4
#define LPMCU_LSADC_CHANNEL_NUM 4

#endif
