/*
 * Copyright (c) CompanyNameMagicTag 2021-2023. All rights reserved.
 * Description: cma extended Interfaces
 * Author: AuthorNameMagicTag
 * Create: 2021-04-24
 */

#ifndef __MEDIA_MEM_CMA_H__
#define __MEDIA_MEM_CMA_H__

#include <linux/cma.h>
#include <linux/device.h>
#include <linux/version.h>

#define NAME_LEN_MAX      64
#define MMA_MMZ_NAME      "ddr"
#define MMA_SMMU_PT_NAME  "smmu"

struct cma_zone {
#if (LINUX_VERSION_CODE <= KERNEL_VERSION(4, 14, 0))
	struct device pdev;
#endif
	struct cma *cma;
	char name[NAME_LEN_MAX];
	unsigned long phys_start;
	unsigned long nbytes;
	unsigned int  reserved;
};

#ifdef CONFIG_MEDIA_MEM
int mma_cma_zone_reserved(const char *name);
size_t mma_get_cma_size(const char *name);
struct cma_zone *mma_get_cma_zone(const char *name);
bool mma_get_cma_zone_range(const char *name, unsigned long *base, unsigned long *size);
#ifdef CONFIG_DMA_CMA
int cma_declare_heap_memory(void);
#endif

int mma_cma_set_name(const char *name, struct cma *cma);
unsigned long bitmap_find_next_zero_area_best(unsigned long *map, unsigned long size,
	unsigned long start, unsigned int nr, unsigned long align_mask);
void cma_bitmap_show(struct cma *cma, size_t count, int ret_val);
struct cma *mma_get_cma(const char *name);

#else
static inline int mma_cma_zone_reserved(struct cma *cma)
{
	return -1;
}

static inline size_t mma_get_cma_size(const char *name)
{
	return 0;
}

static inline struct cma_zone *mma_get_cma_zone(const char *name)
{
	return NULL;
}

static inline bool mma_get_cma_zone_range(const char *name, unsigned long *base, unsigned long *size)
{
	return false;
}

static inline int cma_declare_heap_memory(void)
{
	return 0;
}

static inline int mma_cma_set_name(const char *name, struct cma *cma)
{
	return -1;
}

static inline unsigned long bitmap_find_next_zero_area_best(unsigned long *map, unsigned long size,
	unsigned long start, unsigned int nr, unsigned long align_mask)
{
	return -1;
}

static inline void cma_bitmap_show(struct cma *cma, size_t count, int ret_val)
{
	return;
}

static inline struct cma *mma_get_cma(const char *name)
{
	return NULL;
}

#endif

#endif
