/*
 * Copyright (c) CompanyNameMagicTag 2022-2023. All rights reserved.
 * Description: This interface is provided by the media_mem for the upper layer to invoke.
 * Author: AuthorNameMagicTag
 * Create: 2022-06-30
 */
#ifndef MEDIA_MEM_INTF_H
#define MEDIA_MEM_INTF_H

#include <linux/types.h>


typedef struct {
	const void *data;
	unsigned long len;
}ssm_para;

typedef struct {
	void *client;
	const char *name;
	unsigned long len;
	unsigned long priv_len;
	unsigned int heap_id_mask;
	unsigned int cache;
	ssm_para ssm;
}mma_alloc_info;

#ifdef CONFIG_MEDIA_MEM

void *mma_handle_alloc(mma_alloc_info *mma_info);

void mma_handle_free(void *handle);

void *mma_get_priv_handle(const void *handle);

int mma_handle_set_cache(void *handle, unsigned long flags);

void *mma_handle_kmap(void *handle);

void mma_handle_kunmap(void *handle, void *virt);

phys_addr_t mma_handle_map_smmu(void *handle);
int mma_handle_unmap_smmu(void *handle, phys_addr_t nssmmu);
phys_addr_t mma_handle_map_secsmmu(void *handle);
int mma_handle_unmap_secsmmu(void *handle, phys_addr_t sec_smmu);
phys_addr_t mma_handle_get_phy(void *handle);

size_t mma_handle_size(const void *handle);

int mma_handle_create_fd(void *handle, int flags);
int mma_handle_close_fd(int fd);
void *mma_get_handle_by_fd(int fd);
void mma_handle_put(void *handle);
void mma_handle_get(void *handle);

int mma_handle_clean_cache(void *handle);
int mma_handle_invalid_cache(void *handle);
unsigned int mma_handle_get_heap_id_mask(const void *handle);
int mma_handle_traversal_dmabuf(int (*f)(void *handle, void *data), void *data);
int mma_get_handle_by_addr(void *handle, void *data);
void mma_iommu_get_ptable_info(unsigned long *pt_addr, unsigned long *pt_len,
	unsigned long *pt_offset, unsigned long *err_rdaddr, unsigned long *err_wraddr);
int mma_handle_check_alive(const void *handle);
long mma_handle_get_ref_count(const void *handle);
phys_addr_t mma_iommu_domain_iova_to_phys(unsigned long iova);

#else

static inline void *mma_handle_alloc(mma_alloc_info *mma_info)
{
	return NULL;
}

static inline void mma_handle_free(void *handle)
{
	return;
}

static inline void *mma_get_priv_handle(const void *handle)
{
	return NULL;
}

static inline int mma_handle_set_cache(void *handle, unsigned long flags)
{
	return -1;
}

static inline void *mma_handle_kmap(void *handle)
{
	return NULL;
}

static inline void mma_handle_kunmap(void *handle, void *virt)
{
	return;
}

static inline phys_addr_t mma_handle_map_smmu(void *handle)
{
	return 0;
}
static inline int mma_handle_unmap_smmu(void *handle, phys_addr_t nssmmu)
{
	return -1;
}
static inline phys_addr_t mma_handle_map_secsmmu(void *handle)
{
	return 0;
}
static inline int mma_handle_unmap_secsmmu(void *handle, phys_addr_t sec_smmu)
{
	return -1;
}
static inline phys_addr_t mma_handle_get_phy(void *handle)
{
	return 0;
}

static inline size_t mma_handle_size(const void *handle)
{
	return 0;
}

static inline int mma_handle_create_fd(void *handle, int flags)
{
	return -1;
}
static inline int mma_handle_close_fd(int fd)
{
	return -1;
}
static inline void *mma_get_handle_by_fd(int fd)
{
	return NULL;
}
static inline void mma_handle_put(void *handle)
{
	return;
}
static inline void mma_handle_get(void *handle)
{
	return;
}

static inline int mma_handle_clean_cache(void *handle)
{
	return -1;
}
static inline int mma_handle_invalid_cache(void *handle)
{
	return -1;
}
static inline unsigned int mma_handle_get_heap_id_mask(const void *handle)
{
	return 0;
}
static inline int mma_handle_traversal_dmabuf(int (*f)(void *handle, void *data), void *data)
{
	return -1;
}
static inline int mma_get_handle_by_addr(void *handle, void *data)
{
	return 0;
}
static inline void mma_iommu_get_ptable_info(unsigned long *pt_addr, unsigned long *pt_len,
	unsigned long *pt_offset, unsigned long *err_rdaddr, unsigned long *err_wraddr)
{
	return;
}
static inline int mma_handle_check_alive(const void *handle)
{
	return 0;
}

static inline long mma_handle_get_ref_count(const void *handle)
{
	return -1;
}

static inline phys_addr_t mma_iommu_domain_iova_to_phys(unsigned long iova)
{
	return 0;
}
#endif

#endif
