/*
 * Copyright (c) CompanyNameMagicTag 2022-2023. All rights reserved.
 * Description: media_mem_trace.h
 * Author: AuthorNameMagicTag
 * Create: 2022-06-30
 */
#ifndef _MEDIA_MEM_TRACE_H
#define _MEDIA_MEM_TRACE_H

#include <linux/types.h>
#include <linux/printk.h>

#define MMA_TRACE_LEVEL0 0
#define MMA_TRACE_LEVEL1 1
#define MMA_TRACE_LEVEL2 2

#ifdef CONFIG_MEDIA_MEM
void mma_trace_alloc_start_show(int level, const char *fun, int line, const char* msg, ...);
void mma_trace_alloc_end_show(int level, const char *fun, int line, const char* msg, ...);
void mma_trace_hook_start_show(int level, const char *fun, int line, const char* msg, ...);
void mma_trace_hook_end_show(int level, const char *fun, int line, const char* msg, ...);
void mma_trace_custom_start_show(int level, const char *fun, int line, const char* msg, ...);
void mma_trace_custom_end_show(int level, const char *fun, int line, const char* msg, ...);
const void *mma_handle_get_name_by_fd(int fd);
const void *mma_handle_get_name_by_handle(const void *handle);
bool mma_trace_filters(const char *bufname);
#else
static inline void mma_trace_alloc_start_show(int level, const char *fun, int line, const char* msg, ...)
{
	return;
}
static inline void mma_trace_alloc_end_show(int level, const char *fun, int line, const char* msg, ...)
{
	return;
}
static inline void mma_trace_hook_start_show(int level, const char *fun, int line, const char* msg, ...)
{
	return;
}
static inline void mma_trace_hook_end_show(int level, const char *fun, int line, const char* msg, ...)
{
	return;
}
static inline void mma_trace_custom_start_show(int level, const char *fun, int line, const char* msg, ...)
{
	return;
}
static inline void mma_trace_custom_end_show(int level, const char *fun, int line, const char* msg, ...)
{
	return;
}

static inline const void *mma_handle_get_name_by_fd(int fd)
{
	return NULL;
}

static inline const void *mma_handle_get_name_by_handle(const void *handle)
{
	return NULL;
}
static inline bool mma_trace_filters(const char *bufname)
{
	return false;
}
#endif

#define mma_trace_alloc_start(level, fun, line, bufname, msg, ...) \
do { \
	if (mma_trace_filters(bufname) == true) \
		mma_trace_alloc_start_show(level, fun, line, pr_fmt(msg), ##__VA_ARGS__); \
} while (0)

#define mma_trace_alloc_end(level, fun, line, bufname, msg, ...) \
do { \
	if (mma_trace_filters(bufname) == true) \
		mma_trace_alloc_end_show(level, fun, line, pr_fmt(msg), ##__VA_ARGS__); \
} while (0)

#define mma_trace_hook_start(level, fun, line, bufname, msg, ...) \
do { \
	if (mma_trace_filters(bufname) == true) \
		mma_trace_hook_start_show(level, fun, line, pr_fmt(msg), ##__VA_ARGS__); \
} while (0)

#define mma_trace_hook_end(level, fun, line, bufname, msg, ...) \
do { \
	if (mma_trace_filters(bufname) == true) \
		mma_trace_hook_end_show(level, fun, line, pr_fmt(msg), ##__VA_ARGS__); \
} while (0)

#define mma_trace_custom_start(level, fun, line, bufname, msg, ...) \
do { \
	if (mma_trace_filters(bufname) == true) \
		mma_trace_custom_start_show(level, fun, line, pr_fmt(msg), ##__VA_ARGS__); \
} while (0)

#define mma_trace_custom_end(level, fun, line, bufname, msg, ...) \
do { \
	if (mma_trace_filters(bufname) == true) \
		mma_trace_custom_end_show(level, fun, line, pr_fmt(msg), ##__VA_ARGS__); \
} while (0)

#endif
