/*
 * Copyright (c) CompanyNameMagicTag 2022-2023. All rights reserved.
 * Description: mma_trace.h
 * Author: AuthorNameMagicTag
 * Create: 2022-10-13
 */

#undef TRACE_SYSTEM
#define TRACE_SYSTEM media_mem

#if !defined(_MMA_TRACE_H) || defined(TRACE_HEADER_MULTI_READ)
#define _MEDIA_MEM_TRACE_DEF_H

#include <linux/tracepoint.h>

DECLARE_EVENT_CLASS(media_mem,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info),

	TP_STRUCT__entry(
		__field(int, level)
		__string(fun, fun)
		__field(int, line)
		__string(info, info)
	),

	TP_fast_assign(
		__entry->level = level;
		__assign_str(fun, fun);
		__entry->line = line;
		__assign_str(info, info);
	),

	TP_printk("L%d %s:%d %s",
		__entry->level,
		__get_str(fun),
		__entry->line,
		__get_str(info))
);

DEFINE_EVENT(media_mem, mma_alloc_start,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);

DEFINE_EVENT(media_mem, mma_alloc_end,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);


DEFINE_EVENT(media_mem, mma_free_start,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);

DEFINE_EVENT(media_mem, mma_free_end,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);


DEFINE_EVENT(media_mem, mma_hook_start,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);

DEFINE_EVENT(media_mem, mma_hook_end,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);

DEFINE_EVENT(media_mem, mma_map_start,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);

DEFINE_EVENT(media_mem, mma_map_end,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);


DEFINE_EVENT(media_mem, mma_unmap_start,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);

DEFINE_EVENT(media_mem, mma_unmap_end,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);


DEFINE_EVENT(media_mem, mma_custom_start,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);

DEFINE_EVENT(media_mem, mma_custom_end,

	TP_PROTO(
		int level,
		const char *fun,
		int line,
		const char *info
	),

	TP_ARGS(level, fun, line, info)
);

#endif /* _MEDIA_MEM_TRACE_DEF_H */

/* This part must be outside protection */
#undef TRACE_INCLUDE_PATH
#define TRACE_INCLUDE_PATH media_mem
#define TRACE_INCLUDE_FILE media_mem_trace_def
#include <trace/define_trace.h>

