// SPDX-License-Identifier: GPL-2.0
/*
 * Copyright (c) HengShanCompany 2009-2021. All rights reserved.
 * Description: ion external user-mode interfaces
 * Author: HengShan
 * Create: 2009-12-16
 */

#ifndef _INCLUDE_LINUX_ION_H_
#define _INCLUDE_LINUX_ION_H_

#include "../drivers/staging/android/uapi/ion.h"

struct ssm_private {
	__u32 session_handle; /* session handle, invalid for frame buffer, should be set 0xFFFFFFFF */
	__u32 module_handle;  /* module handle which module the buffer will be attached to */
	__u32 buf_id;         /* buffer ID */
	__u64 addr;       /* Output parameter: Secure Info Addr, only valid for frame buffer */
};

#define BUFFER_NAME_MAX      32

struct drv_ion_allocation_data {
	struct ion_allocation_data alloc_data;
	char name[BUFFER_NAME_MAX];
	struct ssm_private priv;
	int is_attach;
};

struct drv_ion_allocation_data_with_priv {
	struct drv_ion_allocation_data drv_alloc_data;
	__u64 priv_len;
};

struct drv_ion_get_priv_data {
	__u32 fd;
	__u32 priv_fd;
};

/**
 * DOC: EXT_ION_IOC_ALLOC - SOCT allocate memory
 *
 * Takes an ext_ion_allocation_data struct and returns it with the handle field
 * populated with the opaque handle for the allocation.
 */
#define DRV_ION_IOC_ALLOC		_IOWR(ION_IOC_MAGIC, 10, struct drv_ion_allocation_data)


#define DRV_ION_IOC_ALLOC_WITH_PRIV		_IOWR(ION_IOC_MAGIC, 15, struct drv_ion_allocation_data_with_priv)

#define DRV_ION_IOC_GET_PRIV		_IOWR(ION_IOC_MAGIC, 16, struct drv_ion_get_priv_data)

#endif
